// This file has been generated by Py++.

#include "boost/python.hpp"
#include "generators/include/python_CEGUI.h"
#include "Scrollbar.pypp.hpp"

namespace bp = boost::python;

struct Scrollbar_wrapper : CEGUI::Scrollbar, bp::wrapper< CEGUI::Scrollbar > {

    Scrollbar_wrapper(::CEGUI::String const & type, ::CEGUI::String const & name )
    : CEGUI::Scrollbar( boost::ref(type), boost::ref(name) )
      , bp::wrapper< CEGUI::Scrollbar >(){
        // constructor
    
    }

    virtual void banPropertiesForAutoWindow(  ){
        if( bp::override func_banPropertiesForAutoWindow = this->get_override( "banPropertiesForAutoWindow" ) )
            func_banPropertiesForAutoWindow(  );
        else{
            this->CEGUI::Scrollbar::banPropertiesForAutoWindow(  );
        }
    }
    
    virtual void default_banPropertiesForAutoWindow(  ){
        CEGUI::Scrollbar::banPropertiesForAutoWindow( );
    }

    float getAdjustDirectionFromPoint( ::CEGUI::Vector2f const & pt ) const {
        return CEGUI::Scrollbar::getAdjustDirectionFromPoint( boost::ref(pt) );
    }

    float getMaxScrollPosition(  ) const {
        return CEGUI::Scrollbar::getMaxScrollPosition(  );
    }

    float getValueFromThumb(  ) const {
        return CEGUI::Scrollbar::getValueFromThumb(  );
    }

    bool handleDecreaseClicked( ::CEGUI::EventArgs const & e ){
        return CEGUI::Scrollbar::handleDecreaseClicked( boost::ref(e) );
    }

    bool handleIncreaseClicked( ::CEGUI::EventArgs const & e ){
        return CEGUI::Scrollbar::handleIncreaseClicked( boost::ref(e) );
    }

    bool handleThumbMoved( ::CEGUI::EventArgs const & e ){
        return CEGUI::Scrollbar::handleThumbMoved( boost::ref(e) );
    }

    bool handleThumbTrackEnded( ::CEGUI::EventArgs const & e ){
        return CEGUI::Scrollbar::handleThumbTrackEnded( boost::ref(e) );
    }

    bool handleThumbTrackStarted( ::CEGUI::EventArgs const & e ){
        return CEGUI::Scrollbar::handleThumbTrackStarted( boost::ref(e) );
    }

    virtual void initialiseComponents(  ) {
        if( bp::override func_initialiseComponents = this->get_override( "initialiseComponents" ) )
            func_initialiseComponents(  );
        else{
            this->CEGUI::Scrollbar::initialiseComponents(  );
        }
    }
    
    void default_initialiseComponents(  ) {
        CEGUI::Scrollbar::initialiseComponents( );
    }

    bool isAtEnd(  ) const {
        return CEGUI::Scrollbar::isAtEnd(  );
    }

    virtual void onMouseButtonDown( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseButtonDown = this->get_override( "onMouseButtonDown" ) )
            func_onMouseButtonDown( boost::ref(e) );
        else{
            this->CEGUI::Scrollbar::onMouseButtonDown( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseButtonDown( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Scrollbar::onMouseButtonDown( boost::ref(e) );
    }

    virtual void onMouseWheel( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseWheel = this->get_override( "onMouseWheel" ) )
            func_onMouseWheel( boost::ref(e) );
        else{
            this->CEGUI::Scrollbar::onMouseWheel( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseWheel( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Scrollbar::onMouseWheel( boost::ref(e) );
    }

    virtual void onScrollConfigChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onScrollConfigChanged = this->get_override( "onScrollConfigChanged" ) )
            func_onScrollConfigChanged( boost::ref(e) );
        else{
            this->CEGUI::Scrollbar::onScrollConfigChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onScrollConfigChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Scrollbar::onScrollConfigChanged( boost::ref(e) );
    }

    virtual void onScrollPositionChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onScrollPositionChanged = this->get_override( "onScrollPositionChanged" ) )
            func_onScrollPositionChanged( boost::ref(e) );
        else{
            this->CEGUI::Scrollbar::onScrollPositionChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onScrollPositionChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Scrollbar::onScrollPositionChanged( boost::ref(e) );
    }

    virtual void onThumbTrackEnded( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onThumbTrackEnded = this->get_override( "onThumbTrackEnded" ) )
            func_onThumbTrackEnded( boost::ref(e) );
        else{
            this->CEGUI::Scrollbar::onThumbTrackEnded( boost::ref(e) );
        }
    }
    
    virtual void default_onThumbTrackEnded( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Scrollbar::onThumbTrackEnded( boost::ref(e) );
    }

    virtual void onThumbTrackStarted( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onThumbTrackStarted = this->get_override( "onThumbTrackStarted" ) )
            func_onThumbTrackStarted( boost::ref(e) );
        else{
            this->CEGUI::Scrollbar::onThumbTrackStarted( boost::ref(e) );
        }
    }
    
    virtual void default_onThumbTrackStarted( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Scrollbar::onThumbTrackStarted( boost::ref(e) );
    }

    bool setScrollPosition_impl( float const position ){
        return CEGUI::Scrollbar::setScrollPosition_impl( position );
    }

    void updateThumb(  ){
        CEGUI::Scrollbar::updateThumb(  );
    }

    virtual bool validateWindowRenderer( ::CEGUI::WindowRenderer const * renderer ) const {
        if( bp::override func_validateWindowRenderer = this->get_override( "validateWindowRenderer" ) )
            return func_validateWindowRenderer( boost::python::ptr(renderer) );
        else{
            return this->CEGUI::Scrollbar::validateWindowRenderer( boost::python::ptr(renderer) );
        }
    }
    
    virtual bool default_validateWindowRenderer( ::CEGUI::WindowRenderer const * renderer ) const {
        return CEGUI::Scrollbar::validateWindowRenderer( boost::python::ptr(renderer) );
    }

    virtual void addChild_impl( ::CEGUI::Element * element ){
        if( bp::override func_addChild_impl = this->get_override( "addChild_impl" ) )
            func_addChild_impl( boost::python::ptr(element) );
        else{
            this->CEGUI::Window::addChild_impl( boost::python::ptr(element) );
        }
    }
    
    virtual void default_addChild_impl( ::CEGUI::Element * element ){
        CEGUI::Window::addChild_impl( boost::python::ptr(element) );
    }

    void addElementProperties(  ){
        CEGUI::Element::addElementProperties(  );
    }

    void addNamedElementProperties(  ){
        CEGUI::NamedElement::addNamedElementProperties(  );
    }

    void addWindowProperties(  ){
        CEGUI::Window::addWindowProperties(  );
    }

    void addWindowToDrawList( ::CEGUI::Window & wnd, bool at_back=false ){
        CEGUI::Window::addWindowToDrawList( boost::ref(wnd), at_back );
    }

    void allocateRenderingWindow(  ){
        CEGUI::Window::allocateRenderingWindow(  );
    }

    virtual void beginInitialisation(  ) {
        if( bp::override func_beginInitialisation = this->get_override( "beginInitialisation" ) )
            func_beginInitialisation(  );
        else{
            this->CEGUI::Window::beginInitialisation(  );
        }
    }
    
    void default_beginInitialisation(  ) {
        CEGUI::Window::beginInitialisation( );
    }

    void bufferGeometry( ::CEGUI::RenderingContext const & ctx ){
        CEGUI::Window::bufferGeometry( boost::ref(ctx) );
    }

    virtual void cleanupChildren(  ){
        if( bp::override func_cleanupChildren = this->get_override( "cleanupChildren" ) )
            func_cleanupChildren(  );
        else{
            this->CEGUI::Window::cleanupChildren(  );
        }
    }
    
    virtual void default_cleanupChildren(  ){
        CEGUI::Window::cleanupChildren( );
    }

    virtual void cloneChildWidgetsTo( ::CEGUI::Window & target ) const  {
        if( bp::override func_cloneChildWidgetsTo = this->get_override( "cloneChildWidgetsTo" ) )
            func_cloneChildWidgetsTo( boost::ref(target) );
        else{
            this->CEGUI::Window::cloneChildWidgetsTo( boost::ref(target) );
        }
    }
    
    void default_cloneChildWidgetsTo( ::CEGUI::Window & target ) const  {
        CEGUI::Window::cloneChildWidgetsTo( boost::ref(target) );
    }

    virtual void clonePropertiesTo( ::CEGUI::Window & target ) const  {
        if( bp::override func_clonePropertiesTo = this->get_override( "clonePropertiesTo" ) )
            func_clonePropertiesTo( boost::ref(target) );
        else{
            this->CEGUI::Window::clonePropertiesTo( boost::ref(target) );
        }
    }
    
    void default_clonePropertiesTo( ::CEGUI::Window & target ) const  {
        CEGUI::Window::clonePropertiesTo( boost::ref(target) );
    }

    virtual void destroy(  ) {
        if( bp::override func_destroy = this->get_override( "destroy" ) )
            func_destroy(  );
        else{
            this->CEGUI::Window::destroy(  );
        }
    }
    
    void default_destroy(  ) {
        CEGUI::Window::destroy( );
    }

    virtual void drawSelf( ::CEGUI::RenderingContext const & ctx ){
        if( bp::override func_drawSelf = this->get_override( "drawSelf" ) )
            func_drawSelf( boost::ref(ctx) );
        else{
            this->CEGUI::Window::drawSelf( boost::ref(ctx) );
        }
    }
    
    virtual void default_drawSelf( ::CEGUI::RenderingContext const & ctx ){
        CEGUI::Window::drawSelf( boost::ref(ctx) );
    }

    virtual void endInitialisation(  ) {
        if( bp::override func_endInitialisation = this->get_override( "endInitialisation" ) )
            func_endInitialisation(  );
        else{
            this->CEGUI::Window::endInitialisation(  );
        }
    }
    
    void default_endInitialisation(  ) {
        CEGUI::Window::endInitialisation( );
    }

    void fireAreaChangeEvents( bool const moved, bool const sized ){
        CEGUI::Element::fireAreaChangeEvents( moved, sized );
    }

    virtual void fireEvent( ::CEGUI::String const & name, ::CEGUI::EventArgs & args, ::CEGUI::String const & eventNamespace="" ) {
        if( bp::override func_fireEvent = this->get_override( "fireEvent" ) )
            func_fireEvent( boost::ref(name), boost::ref(args), boost::ref(eventNamespace) );
        else{
            this->CEGUI::EventSet::fireEvent( boost::ref(name), boost::ref(args), boost::ref(eventNamespace) );
        }
    }
    
    void default_fireEvent( ::CEGUI::String const & name, ::CEGUI::EventArgs & args, ::CEGUI::String const & eventNamespace="" ) {
        CEGUI::EventSet::fireEvent( boost::ref(name), boost::ref(args), boost::ref(eventNamespace) );
    }

    void fireEvent_impl( ::CEGUI::String const & name, ::CEGUI::EventArgs & args ){
        CEGUI::EventSet::fireEvent_impl( boost::ref(name), boost::ref(args) );
    }

    void generateAutoRepeatEvent( ::CEGUI::MouseButton button ){
        CEGUI::Window::generateAutoRepeatEvent( button );
    }

    virtual ::CEGUI::NamedElement * getChildByNamePath_impl( ::CEGUI::String const & name_path ) const {
        if( bp::override func_getChildByNamePath_impl = this->get_override( "getChildByNamePath_impl" ) )
            return func_getChildByNamePath_impl( boost::ref(name_path) );
        else{
            return this->CEGUI::NamedElement::getChildByNamePath_impl( boost::ref(name_path) );
        }
    }
    
    virtual ::CEGUI::NamedElement * default_getChildByNamePath_impl( ::CEGUI::String const & name_path ) const {
        return CEGUI::NamedElement::getChildByNamePath_impl( boost::ref(name_path) );
    }

    virtual ::CEGUI::NamedElement * getChildByNameRecursive_impl( ::CEGUI::String const & name ) const {
        if( bp::override func_getChildByNameRecursive_impl = this->get_override( "getChildByNameRecursive_impl" ) )
            return func_getChildByNameRecursive_impl( boost::ref(name) );
        else{
            return this->CEGUI::NamedElement::getChildByNameRecursive_impl( boost::ref(name) );
        }
    }
    
    virtual ::CEGUI::NamedElement * default_getChildByNameRecursive_impl( ::CEGUI::String const & name ) const {
        return CEGUI::NamedElement::getChildByNameRecursive_impl( boost::ref(name) );
    }

    virtual ::CEGUI::Rectf getHitTestRect_impl(  ) const {
        if( bp::override func_getHitTestRect_impl = this->get_override( "getHitTestRect_impl" ) )
            return func_getHitTestRect_impl(  );
        else{
            return this->CEGUI::Window::getHitTestRect_impl(  );
        }
    }
    
    virtual ::CEGUI::Rectf default_getHitTestRect_impl(  ) const {
        return CEGUI::Window::getHitTestRect_impl( );
    }

    virtual ::CEGUI::Rectf getInnerRectClipper_impl(  ) const {
        if( bp::override func_getInnerRectClipper_impl = this->get_override( "getInnerRectClipper_impl" ) )
            return func_getInnerRectClipper_impl(  );
        else{
            return this->CEGUI::Window::getInnerRectClipper_impl(  );
        }
    }
    
    virtual ::CEGUI::Rectf default_getInnerRectClipper_impl(  ) const {
        return CEGUI::Window::getInnerRectClipper_impl( );
    }

    virtual ::CEGUI::Rectf getOuterRectClipper_impl(  ) const {
        if( bp::override func_getOuterRectClipper_impl = this->get_override( "getOuterRectClipper_impl" ) )
            return func_getOuterRectClipper_impl(  );
        else{
            return this->CEGUI::Window::getOuterRectClipper_impl(  );
        }
    }
    
    virtual ::CEGUI::Rectf default_getOuterRectClipper_impl(  ) const {
        return CEGUI::Window::getOuterRectClipper_impl( );
    }

    ::CEGUI::Rectf getParentElementClipIntersection( ::CEGUI::Rectf const & unclipped_area ) const {
        return CEGUI::Window::getParentElementClipIntersection( boost::ref(unclipped_area) );
    }

    virtual void getRenderingContext_impl( ::CEGUI::RenderingContext & ctx ) const  {
        if( bp::override func_getRenderingContext_impl = this->get_override( "getRenderingContext_impl" ) )
            func_getRenderingContext_impl( boost::ref(ctx) );
        else{
            this->CEGUI::Window::getRenderingContext_impl( boost::ref(ctx) );
        }
    }
    
    void default_getRenderingContext_impl( ::CEGUI::RenderingContext & ctx ) const  {
        CEGUI::Window::getRenderingContext_impl( boost::ref(ctx) );
    }

    ::CEGUI::ScriptModule * getScriptModule(  ) const {
        return CEGUI::EventSet::getScriptModule(  );
    }

    virtual ::CEGUI::Rectf getUnclippedInnerRect_impl( bool skipAllPixelAlignment ) const {
        if( bp::override func_getUnclippedInnerRect_impl = this->get_override( "getUnclippedInnerRect_impl" ) )
            return func_getUnclippedInnerRect_impl( skipAllPixelAlignment );
        else{
            return this->CEGUI::Window::getUnclippedInnerRect_impl( skipAllPixelAlignment );
        }
    }
    
    virtual ::CEGUI::Rectf default_getUnclippedInnerRect_impl( bool skipAllPixelAlignment ) const {
        return CEGUI::Window::getUnclippedInnerRect_impl( skipAllPixelAlignment );
    }

    virtual ::CEGUI::Rectf getUnclippedOuterRect_impl( bool skipAllPixelAlignment ) const {
        if( bp::override func_getUnclippedOuterRect_impl = this->get_override( "getUnclippedOuterRect_impl" ) )
            return func_getUnclippedOuterRect_impl( skipAllPixelAlignment );
        else{
            return this->CEGUI::Element::getUnclippedOuterRect_impl( skipAllPixelAlignment );
        }
    }
    
    virtual ::CEGUI::Rectf default_getUnclippedOuterRect_impl( bool skipAllPixelAlignment ) const {
        return CEGUI::Element::getUnclippedOuterRect_impl( skipAllPixelAlignment );
    }

    ::CEGUI::Window const * getWindowAttachedToCommonAncestor( ::CEGUI::Window const & wnd ) const {
        return CEGUI::Window::getWindowAttachedToCommonAncestor( boost::ref(wnd) );
    }

    virtual bool handleFontRenderSizeChange( ::CEGUI::EventArgs const & args ){
        if( bp::override func_handleFontRenderSizeChange = this->get_override( "handleFontRenderSizeChange" ) )
            return func_handleFontRenderSizeChange( boost::ref(args) );
        else{
            return this->CEGUI::Window::handleFontRenderSizeChange( boost::ref(args) );
        }
    }
    
    virtual bool default_handleFontRenderSizeChange( ::CEGUI::EventArgs const & args ){
        return CEGUI::Window::handleFontRenderSizeChange( boost::ref(args) );
    }

    void initialiseClippers( ::CEGUI::RenderingContext const & ctx ){
        CEGUI::Window::initialiseClippers( boost::ref(ctx) );
    }

    void invalidate_impl( bool const recursive ){
        CEGUI::Window::invalidate_impl( recursive );
    }

    virtual bool isHit( ::CEGUI::Vector2f const & position, bool const allow_disabled=false ) const  {
        if( bp::override func_isHit = this->get_override( "isHit" ) )
            return func_isHit( boost::ref(position), allow_disabled );
        else{
            return this->CEGUI::Window::isHit( boost::ref(position), allow_disabled );
        }
    }
    
    bool default_isHit( ::CEGUI::Vector2f const & position, bool const allow_disabled=false ) const  {
        return CEGUI::Window::isHit( boost::ref(position), allow_disabled );
    }

    bool isHitTargetWindow( ::CEGUI::Vector2f const & position, bool allow_disabled ) const {
        return CEGUI::Window::isHitTargetWindow( boost::ref(position), allow_disabled );
    }

    bool isInnerRectSizeChanged(  ) const {
        return CEGUI::Element::isInnerRectSizeChanged(  );
    }

    bool isPropertyAtDefault( ::CEGUI::Property const * property ) const {
        return CEGUI::Window::isPropertyAtDefault( boost::python::ptr(property) );
    }

    bool isTopOfZOrder(  ) const {
        return CEGUI::Window::isTopOfZOrder(  );
    }

    void layoutLookNFeelChildWidgets(  ){
        CEGUI::Window::layoutLookNFeelChildWidgets(  );
    }

    void markCachedWindowRectsInvalid(  ){
        CEGUI::Window::markCachedWindowRectsInvalid(  );
    }

    virtual bool moveToFront_impl( bool wasClicked ){
        if( bp::override func_moveToFront_impl = this->get_override( "moveToFront_impl" ) )
            return func_moveToFront_impl( wasClicked );
        else{
            return this->CEGUI::Window::moveToFront_impl( wasClicked );
        }
    }
    
    virtual bool default_moveToFront_impl( bool wasClicked ){
        return CEGUI::Window::moveToFront_impl( wasClicked );
    }

    void notifyChildrenOfSizeChange( bool const non_client, bool const client ){
        CEGUI::Element::notifyChildrenOfSizeChange( non_client, client );
    }

    void notifyClippingChanged(  ){
        CEGUI::Window::notifyClippingChanged(  );
    }

    virtual void notifyScreenAreaChanged( bool recursive=true ) {
        if( bp::override func_notifyScreenAreaChanged = this->get_override( "notifyScreenAreaChanged" ) )
            func_notifyScreenAreaChanged( recursive );
        else{
            this->CEGUI::Window::notifyScreenAreaChanged( recursive );
        }
    }
    
    void default_notifyScreenAreaChanged( bool recursive=true ) {
        CEGUI::Window::notifyScreenAreaChanged( recursive );
    }

    virtual void onActivated( ::CEGUI::ActivationEventArgs & e ){
        if( bp::override func_onActivated = this->get_override( "onActivated" ) )
            func_onActivated( boost::ref(e) );
        else{
            this->CEGUI::Window::onActivated( boost::ref(e) );
        }
    }
    
    virtual void default_onActivated( ::CEGUI::ActivationEventArgs & e ){
        CEGUI::Window::onActivated( boost::ref(e) );
    }

    virtual void onAlphaChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onAlphaChanged = this->get_override( "onAlphaChanged" ) )
            func_onAlphaChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onAlphaChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onAlphaChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onAlphaChanged( boost::ref(e) );
    }

    virtual void onAlwaysOnTopChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onAlwaysOnTopChanged = this->get_override( "onAlwaysOnTopChanged" ) )
            func_onAlwaysOnTopChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onAlwaysOnTopChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onAlwaysOnTopChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onAlwaysOnTopChanged( boost::ref(e) );
    }

    virtual void onCaptureGained( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onCaptureGained = this->get_override( "onCaptureGained" ) )
            func_onCaptureGained( boost::ref(e) );
        else{
            this->CEGUI::Window::onCaptureGained( boost::ref(e) );
        }
    }
    
    virtual void default_onCaptureGained( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onCaptureGained( boost::ref(e) );
    }

    virtual void onCaptureLost( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onCaptureLost = this->get_override( "onCaptureLost" ) )
            func_onCaptureLost( boost::ref(e) );
        else{
            this->CEGUI::Window::onCaptureLost( boost::ref(e) );
        }
    }
    
    virtual void default_onCaptureLost( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onCaptureLost( boost::ref(e) );
    }

    virtual void onCharacter( ::CEGUI::KeyEventArgs & e ){
        if( bp::override func_onCharacter = this->get_override( "onCharacter" ) )
            func_onCharacter( boost::ref(e) );
        else{
            this->CEGUI::Window::onCharacter( boost::ref(e) );
        }
    }
    
    virtual void default_onCharacter( ::CEGUI::KeyEventArgs & e ){
        CEGUI::Window::onCharacter( boost::ref(e) );
    }

    virtual void onChildAdded( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onChildAdded = this->get_override( "onChildAdded" ) )
            func_onChildAdded( boost::ref(e) );
        else{
            this->CEGUI::Window::onChildAdded( boost::ref(e) );
        }
    }
    
    virtual void default_onChildAdded( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Window::onChildAdded( boost::ref(e) );
    }

    virtual void onChildRemoved( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onChildRemoved = this->get_override( "onChildRemoved" ) )
            func_onChildRemoved( boost::ref(e) );
        else{
            this->CEGUI::Window::onChildRemoved( boost::ref(e) );
        }
    }
    
    virtual void default_onChildRemoved( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Window::onChildRemoved( boost::ref(e) );
    }

    virtual void onClippingChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onClippingChanged = this->get_override( "onClippingChanged" ) )
            func_onClippingChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onClippingChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onClippingChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onClippingChanged( boost::ref(e) );
    }

    virtual void onDeactivated( ::CEGUI::ActivationEventArgs & e ){
        if( bp::override func_onDeactivated = this->get_override( "onDeactivated" ) )
            func_onDeactivated( boost::ref(e) );
        else{
            this->CEGUI::Window::onDeactivated( boost::ref(e) );
        }
    }
    
    virtual void default_onDeactivated( ::CEGUI::ActivationEventArgs & e ){
        CEGUI::Window::onDeactivated( boost::ref(e) );
    }

    virtual void onDestructionStarted( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onDestructionStarted = this->get_override( "onDestructionStarted" ) )
            func_onDestructionStarted( boost::ref(e) );
        else{
            this->CEGUI::Window::onDestructionStarted( boost::ref(e) );
        }
    }
    
    virtual void default_onDestructionStarted( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onDestructionStarted( boost::ref(e) );
    }

    virtual void onDisabled( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onDisabled = this->get_override( "onDisabled" ) )
            func_onDisabled( boost::ref(e) );
        else{
            this->CEGUI::Window::onDisabled( boost::ref(e) );
        }
    }
    
    virtual void default_onDisabled( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onDisabled( boost::ref(e) );
    }

    virtual void onDragDropItemDropped( ::CEGUI::DragDropEventArgs & e ){
        if( bp::override func_onDragDropItemDropped = this->get_override( "onDragDropItemDropped" ) )
            func_onDragDropItemDropped( boost::ref(e) );
        else{
            this->CEGUI::Window::onDragDropItemDropped( boost::ref(e) );
        }
    }
    
    virtual void default_onDragDropItemDropped( ::CEGUI::DragDropEventArgs & e ){
        CEGUI::Window::onDragDropItemDropped( boost::ref(e) );
    }

    virtual void onDragDropItemEnters( ::CEGUI::DragDropEventArgs & e ){
        if( bp::override func_onDragDropItemEnters = this->get_override( "onDragDropItemEnters" ) )
            func_onDragDropItemEnters( boost::ref(e) );
        else{
            this->CEGUI::Window::onDragDropItemEnters( boost::ref(e) );
        }
    }
    
    virtual void default_onDragDropItemEnters( ::CEGUI::DragDropEventArgs & e ){
        CEGUI::Window::onDragDropItemEnters( boost::ref(e) );
    }

    virtual void onDragDropItemLeaves( ::CEGUI::DragDropEventArgs & e ){
        if( bp::override func_onDragDropItemLeaves = this->get_override( "onDragDropItemLeaves" ) )
            func_onDragDropItemLeaves( boost::ref(e) );
        else{
            this->CEGUI::Window::onDragDropItemLeaves( boost::ref(e) );
        }
    }
    
    virtual void default_onDragDropItemLeaves( ::CEGUI::DragDropEventArgs & e ){
        CEGUI::Window::onDragDropItemLeaves( boost::ref(e) );
    }

    virtual void onEnabled( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onEnabled = this->get_override( "onEnabled" ) )
            func_onEnabled( boost::ref(e) );
        else{
            this->CEGUI::Window::onEnabled( boost::ref(e) );
        }
    }
    
    virtual void default_onEnabled( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onEnabled( boost::ref(e) );
    }

    virtual void onFontChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onFontChanged = this->get_override( "onFontChanged" ) )
            func_onFontChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onFontChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onFontChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onFontChanged( boost::ref(e) );
    }

    virtual void onHidden( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onHidden = this->get_override( "onHidden" ) )
            func_onHidden( boost::ref(e) );
        else{
            this->CEGUI::Window::onHidden( boost::ref(e) );
        }
    }
    
    virtual void default_onHidden( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onHidden( boost::ref(e) );
    }

    virtual void onHorizontalAlignmentChanged( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onHorizontalAlignmentChanged = this->get_override( "onHorizontalAlignmentChanged" ) )
            func_onHorizontalAlignmentChanged( boost::ref(e) );
        else{
            this->CEGUI::Element::onHorizontalAlignmentChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onHorizontalAlignmentChanged( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Element::onHorizontalAlignmentChanged( boost::ref(e) );
    }

    virtual void onIDChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onIDChanged = this->get_override( "onIDChanged" ) )
            func_onIDChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onIDChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onIDChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onIDChanged( boost::ref(e) );
    }

    virtual void onInheritsAlphaChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onInheritsAlphaChanged = this->get_override( "onInheritsAlphaChanged" ) )
            func_onInheritsAlphaChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onInheritsAlphaChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onInheritsAlphaChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onInheritsAlphaChanged( boost::ref(e) );
    }

    virtual void onInvalidated( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onInvalidated = this->get_override( "onInvalidated" ) )
            func_onInvalidated( boost::ref(e) );
        else{
            this->CEGUI::Window::onInvalidated( boost::ref(e) );
        }
    }
    
    virtual void default_onInvalidated( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onInvalidated( boost::ref(e) );
    }

    virtual void onKeyDown( ::CEGUI::KeyEventArgs & e ){
        if( bp::override func_onKeyDown = this->get_override( "onKeyDown" ) )
            func_onKeyDown( boost::ref(e) );
        else{
            this->CEGUI::Window::onKeyDown( boost::ref(e) );
        }
    }
    
    virtual void default_onKeyDown( ::CEGUI::KeyEventArgs & e ){
        CEGUI::Window::onKeyDown( boost::ref(e) );
    }

    virtual void onKeyUp( ::CEGUI::KeyEventArgs & e ){
        if( bp::override func_onKeyUp = this->get_override( "onKeyUp" ) )
            func_onKeyUp( boost::ref(e) );
        else{
            this->CEGUI::Window::onKeyUp( boost::ref(e) );
        }
    }
    
    virtual void default_onKeyUp( ::CEGUI::KeyEventArgs & e ){
        CEGUI::Window::onKeyUp( boost::ref(e) );
    }

    virtual void onMarginChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onMarginChanged = this->get_override( "onMarginChanged" ) )
            func_onMarginChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onMarginChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onMarginChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onMarginChanged( boost::ref(e) );
    }

    virtual void onMouseButtonUp( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseButtonUp = this->get_override( "onMouseButtonUp" ) )
            func_onMouseButtonUp( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseButtonUp( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseButtonUp( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseButtonUp( boost::ref(e) );
    }

    virtual void onMouseClicked( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseClicked = this->get_override( "onMouseClicked" ) )
            func_onMouseClicked( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseClicked( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseClicked( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseClicked( boost::ref(e) );
    }

    virtual void onMouseDoubleClicked( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseDoubleClicked = this->get_override( "onMouseDoubleClicked" ) )
            func_onMouseDoubleClicked( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseDoubleClicked( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseDoubleClicked( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseDoubleClicked( boost::ref(e) );
    }

    virtual void onMouseEnters( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseEnters = this->get_override( "onMouseEnters" ) )
            func_onMouseEnters( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseEnters( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseEnters( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseEnters( boost::ref(e) );
    }

    virtual void onMouseEntersArea( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseEntersArea = this->get_override( "onMouseEntersArea" ) )
            func_onMouseEntersArea( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseEntersArea( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseEntersArea( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseEntersArea( boost::ref(e) );
    }

    virtual void onMouseLeaves( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseLeaves = this->get_override( "onMouseLeaves" ) )
            func_onMouseLeaves( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseLeaves( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseLeaves( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseLeaves( boost::ref(e) );
    }

    virtual void onMouseLeavesArea( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseLeavesArea = this->get_override( "onMouseLeavesArea" ) )
            func_onMouseLeavesArea( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseLeavesArea( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseLeavesArea( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseLeavesArea( boost::ref(e) );
    }

    virtual void onMouseMove( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseMove = this->get_override( "onMouseMove" ) )
            func_onMouseMove( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseMove( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseMove( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseMove( boost::ref(e) );
    }

    virtual void onMouseTripleClicked( ::CEGUI::MouseEventArgs & e ){
        if( bp::override func_onMouseTripleClicked = this->get_override( "onMouseTripleClicked" ) )
            func_onMouseTripleClicked( boost::ref(e) );
        else{
            this->CEGUI::Window::onMouseTripleClicked( boost::ref(e) );
        }
    }
    
    virtual void default_onMouseTripleClicked( ::CEGUI::MouseEventArgs & e ){
        CEGUI::Window::onMouseTripleClicked( boost::ref(e) );
    }

    virtual void onMoved( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onMoved = this->get_override( "onMoved" ) )
            func_onMoved( boost::ref(e) );
        else{
            this->CEGUI::Window::onMoved( boost::ref(e) );
        }
    }
    
    virtual void default_onMoved( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Window::onMoved( boost::ref(e) );
    }

    virtual void onNameChanged( ::CEGUI::NamedElementEventArgs & e ){
        if( bp::override func_onNameChanged = this->get_override( "onNameChanged" ) )
            func_onNameChanged( boost::ref(e) );
        else{
            this->CEGUI::NamedElement::onNameChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onNameChanged( ::CEGUI::NamedElementEventArgs & e ){
        CEGUI::NamedElement::onNameChanged( boost::ref(e) );
    }

    virtual void onNonClientChanged( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onNonClientChanged = this->get_override( "onNonClientChanged" ) )
            func_onNonClientChanged( boost::ref(e) );
        else{
            this->CEGUI::Element::onNonClientChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onNonClientChanged( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Element::onNonClientChanged( boost::ref(e) );
    }

    virtual void onParentDestroyChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onParentDestroyChanged = this->get_override( "onParentDestroyChanged" ) )
            func_onParentDestroyChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onParentDestroyChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onParentDestroyChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onParentDestroyChanged( boost::ref(e) );
    }

    virtual void onParentSized( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onParentSized = this->get_override( "onParentSized" ) )
            func_onParentSized( boost::ref(e) );
        else{
            this->CEGUI::Window::onParentSized( boost::ref(e) );
        }
    }
    
    virtual void default_onParentSized( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Window::onParentSized( boost::ref(e) );
    }

    virtual void onRenderingEnded( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onRenderingEnded = this->get_override( "onRenderingEnded" ) )
            func_onRenderingEnded( boost::ref(e) );
        else{
            this->CEGUI::Window::onRenderingEnded( boost::ref(e) );
        }
    }
    
    virtual void default_onRenderingEnded( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onRenderingEnded( boost::ref(e) );
    }

    virtual void onRenderingStarted( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onRenderingStarted = this->get_override( "onRenderingStarted" ) )
            func_onRenderingStarted( boost::ref(e) );
        else{
            this->CEGUI::Window::onRenderingStarted( boost::ref(e) );
        }
    }
    
    virtual void default_onRenderingStarted( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onRenderingStarted( boost::ref(e) );
    }

    virtual void onRotated( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onRotated = this->get_override( "onRotated" ) )
            func_onRotated( boost::ref(e) );
        else{
            this->CEGUI::Window::onRotated( boost::ref(e) );
        }
    }
    
    virtual void default_onRotated( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Window::onRotated( boost::ref(e) );
    }

    virtual void onShown( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onShown = this->get_override( "onShown" ) )
            func_onShown( boost::ref(e) );
        else{
            this->CEGUI::Window::onShown( boost::ref(e) );
        }
    }
    
    virtual void default_onShown( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onShown( boost::ref(e) );
    }

    virtual void onSized( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onSized = this->get_override( "onSized" ) )
            func_onSized( boost::ref(e) );
        else{
            this->CEGUI::Window::onSized( boost::ref(e) );
        }
    }
    
    virtual void default_onSized( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Window::onSized( boost::ref(e) );
    }

    virtual void onTextChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onTextChanged = this->get_override( "onTextChanged" ) )
            func_onTextChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onTextChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onTextChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onTextChanged( boost::ref(e) );
    }

    virtual void onTextParsingChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onTextParsingChanged = this->get_override( "onTextParsingChanged" ) )
            func_onTextParsingChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onTextParsingChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onTextParsingChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onTextParsingChanged( boost::ref(e) );
    }

    virtual void onVerticalAlignmentChanged( ::CEGUI::ElementEventArgs & e ){
        if( bp::override func_onVerticalAlignmentChanged = this->get_override( "onVerticalAlignmentChanged" ) )
            func_onVerticalAlignmentChanged( boost::ref(e) );
        else{
            this->CEGUI::Element::onVerticalAlignmentChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onVerticalAlignmentChanged( ::CEGUI::ElementEventArgs & e ){
        CEGUI::Element::onVerticalAlignmentChanged( boost::ref(e) );
    }

    virtual void onWindowRendererAttached( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onWindowRendererAttached = this->get_override( "onWindowRendererAttached" ) )
            func_onWindowRendererAttached( boost::ref(e) );
        else{
            this->CEGUI::Window::onWindowRendererAttached( boost::ref(e) );
        }
    }
    
    virtual void default_onWindowRendererAttached( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onWindowRendererAttached( boost::ref(e) );
    }

    virtual void onWindowRendererDetached( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onWindowRendererDetached = this->get_override( "onWindowRendererDetached" ) )
            func_onWindowRendererDetached( boost::ref(e) );
        else{
            this->CEGUI::Window::onWindowRendererDetached( boost::ref(e) );
        }
    }
    
    virtual void default_onWindowRendererDetached( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onWindowRendererDetached( boost::ref(e) );
    }

    virtual void onZChange_impl(  ){
        if( bp::override func_onZChange_impl = this->get_override( "onZChange_impl" ) )
            func_onZChange_impl(  );
        else{
            this->CEGUI::Window::onZChange_impl(  );
        }
    }
    
    virtual void default_onZChange_impl(  ){
        CEGUI::Window::onZChange_impl( );
    }

    virtual void onZChanged( ::CEGUI::WindowEventArgs & e ){
        if( bp::override func_onZChanged = this->get_override( "onZChanged" ) )
            func_onZChanged( boost::ref(e) );
        else{
            this->CEGUI::Window::onZChanged( boost::ref(e) );
        }
    }
    
    virtual void default_onZChanged( ::CEGUI::WindowEventArgs & e ){
        CEGUI::Window::onZChanged( boost::ref(e) );
    }

    virtual void performChildWindowLayout( bool nonclient_sized_hint=false, bool client_sized_hint=false ) {
        if( bp::override func_performChildWindowLayout = this->get_override( "performChildWindowLayout" ) )
            func_performChildWindowLayout( nonclient_sized_hint, client_sized_hint );
        else{
            this->CEGUI::Window::performChildWindowLayout( nonclient_sized_hint, client_sized_hint );
        }
    }
    
    void default_performChildWindowLayout( bool nonclient_sized_hint=false, bool client_sized_hint=false ) {
        CEGUI::Window::performChildWindowLayout( nonclient_sized_hint, client_sized_hint );
    }

    virtual bool performCopy( ::CEGUI::Clipboard & clipboard ) {
        if( bp::override func_performCopy = this->get_override( "performCopy" ) )
            return func_performCopy( boost::ref(clipboard) );
        else{
            return this->CEGUI::Window::performCopy( boost::ref(clipboard) );
        }
    }
    
    bool default_performCopy( ::CEGUI::Clipboard & clipboard ) {
        return CEGUI::Window::performCopy( boost::ref(clipboard) );
    }

    virtual bool performCut( ::CEGUI::Clipboard & clipboard ) {
        if( bp::override func_performCut = this->get_override( "performCut" ) )
            return func_performCut( boost::ref(clipboard) );
        else{
            return this->CEGUI::Window::performCut( boost::ref(clipboard) );
        }
    }
    
    bool default_performCut( ::CEGUI::Clipboard & clipboard ) {
        return CEGUI::Window::performCut( boost::ref(clipboard) );
    }

    virtual bool performPaste( ::CEGUI::Clipboard & clipboard ) {
        if( bp::override func_performPaste = this->get_override( "performPaste" ) )
            return func_performPaste( boost::ref(clipboard) );
        else{
            return this->CEGUI::Window::performPaste( boost::ref(clipboard) );
        }
    }
    
    bool default_performPaste( ::CEGUI::Clipboard & clipboard ) {
        return CEGUI::Window::performPaste( boost::ref(clipboard) );
    }

    virtual void populateGeometryBuffer(  ){
        if( bp::override func_populateGeometryBuffer = this->get_override( "populateGeometryBuffer" ) )
            func_populateGeometryBuffer(  );
        else{
            this->CEGUI::Window::populateGeometryBuffer(  );
        }
    }
    
    virtual void default_populateGeometryBuffer(  ){
        CEGUI::Window::populateGeometryBuffer( );
    }

    void queueGeometry( ::CEGUI::RenderingContext const & ctx ){
        CEGUI::Window::queueGeometry( boost::ref(ctx) );
    }

    void releaseRenderingWindow(  ){
        CEGUI::Window::releaseRenderingWindow(  );
    }

    virtual void removeChild_impl( ::CEGUI::Element * element ){
        if( bp::override func_removeChild_impl = this->get_override( "removeChild_impl" ) )
            func_removeChild_impl( boost::python::ptr(element) );
        else{
            this->CEGUI::Window::removeChild_impl( boost::python::ptr(element) );
        }
    }
    
    virtual void default_removeChild_impl( ::CEGUI::Element * element ){
        CEGUI::Window::removeChild_impl( boost::python::ptr(element) );
    }

    void removeWindowFromDrawList( ::CEGUI::Window const & wnd ){
        CEGUI::Window::removeWindowFromDrawList( boost::ref(wnd) );
    }

    virtual void setArea( ::CEGUI::UVector2 const & pos, ::CEGUI::USize const & size ) {
        if( bp::override func_setArea = this->get_override( "setArea" ) )
            func_setArea( boost::ref(pos), boost::ref(size) );
        else{
            this->CEGUI::Element::setArea( boost::ref(pos), boost::ref(size) );
        }
    }
    
    void default_setArea( ::CEGUI::UVector2 const & pos, ::CEGUI::USize const & size ) {
        CEGUI::Element::setArea( boost::ref(pos), boost::ref(size) );
    }

    virtual void setArea_impl( ::CEGUI::UVector2 const & pos, ::CEGUI::USize const & size, bool topLeftSizing=false, bool fireEvents=true ){
        if( bp::override func_setArea_impl = this->get_override( "setArea_impl" ) )
            func_setArea_impl( boost::ref(pos), boost::ref(size), topLeftSizing, fireEvents );
        else{
            this->CEGUI::Window::setArea_impl( boost::ref(pos), boost::ref(size), topLeftSizing, fireEvents );
        }
    }
    
    virtual void default_setArea_impl( ::CEGUI::UVector2 const & pos, ::CEGUI::USize const & size, bool topLeftSizing=false, bool fireEvents=true ){
        CEGUI::Window::setArea_impl( boost::ref(pos), boost::ref(size), topLeftSizing, fireEvents );
    }

    virtual void setHorizontalAlignment( ::CEGUI::HorizontalAlignment const alignment ) {
        if( bp::override func_setHorizontalAlignment = this->get_override( "setHorizontalAlignment" ) )
            func_setHorizontalAlignment( alignment );
        else{
            this->CEGUI::Element::setHorizontalAlignment( alignment );
        }
    }
    
    void default_setHorizontalAlignment( ::CEGUI::HorizontalAlignment const alignment ) {
        CEGUI::Element::setHorizontalAlignment( alignment );
    }

    virtual void setLookNFeel( ::CEGUI::String const & look ) {
        if( bp::override func_setLookNFeel = this->get_override( "setLookNFeel" ) )
            func_setLookNFeel( boost::ref(look) );
        else{
            this->CEGUI::Window::setLookNFeel( boost::ref(look) );
        }
    }
    
    void default_setLookNFeel( ::CEGUI::String const & look ) {
        CEGUI::Window::setLookNFeel( boost::ref(look) );
    }

    virtual void setMargin( ::CEGUI::UBox const & margin ) {
        if( bp::override func_setMargin = this->get_override( "setMargin" ) )
            func_setMargin( boost::ref(margin) );
        else{
            this->CEGUI::Window::setMargin( boost::ref(margin) );
        }
    }
    
    void default_setMargin( ::CEGUI::UBox const & margin ) {
        CEGUI::Window::setMargin( boost::ref(margin) );
    }

    virtual void setName( ::CEGUI::String const & name ) {
        if( bp::override func_setName = this->get_override( "setName" ) )
            func_setName( boost::ref(name) );
        else{
            this->CEGUI::NamedElement::setName( boost::ref(name) );
        }
    }
    
    void default_setName( ::CEGUI::String const & name ) {
        CEGUI::NamedElement::setName( boost::ref(name) );
    }

    virtual void setParent( ::CEGUI::Element * parent ){
        if( bp::override func_setParent = this->get_override( "setParent" ) )
            func_setParent( boost::python::ptr(parent) );
        else{
            this->CEGUI::Window::setParent( boost::python::ptr(parent) );
        }
    }
    
    virtual void default_setParent( ::CEGUI::Element * parent ){
        CEGUI::Window::setParent( boost::python::ptr(parent) );
    }

    virtual void setVerticalAlignment( ::CEGUI::VerticalAlignment const alignment ) {
        if( bp::override func_setVerticalAlignment = this->get_override( "setVerticalAlignment" ) )
            func_setVerticalAlignment( alignment );
        else{
            this->CEGUI::Element::setVerticalAlignment( alignment );
        }
    }
    
    void default_setVerticalAlignment( ::CEGUI::VerticalAlignment const alignment ) {
        CEGUI::Element::setVerticalAlignment( alignment );
    }

    virtual ::CEGUI::RefCounted< CEGUI::BoundSlot > subscribeScriptedEvent( ::CEGUI::String const & name, ::CEGUI::String const & subscriber_name ) {
        if( bp::override func_subscribeScriptedEvent = this->get_override( "subscribeScriptedEvent" ) )
            return func_subscribeScriptedEvent( boost::ref(name), boost::ref(subscriber_name) );
        else{
            return this->CEGUI::EventSet::subscribeScriptedEvent( boost::ref(name), boost::ref(subscriber_name) );
        }
    }
    
    ::CEGUI::RefCounted< CEGUI::BoundSlot > default_subscribeScriptedEvent( ::CEGUI::String const & name, ::CEGUI::String const & subscriber_name ) {
        return CEGUI::EventSet::subscribeScriptedEvent( boost::ref(name), boost::ref(subscriber_name) );
    }

    virtual ::CEGUI::RefCounted< CEGUI::BoundSlot > subscribeScriptedEvent( ::CEGUI::String const & name, unsigned int group, ::CEGUI::String const & subscriber_name ) {
        if( bp::override func_subscribeScriptedEvent = this->get_override( "subscribeScriptedEvent" ) )
            return func_subscribeScriptedEvent( boost::ref(name), group, boost::ref(subscriber_name) );
        else{
            return this->CEGUI::EventSet::subscribeScriptedEvent( boost::ref(name), group, boost::ref(subscriber_name) );
        }
    }
    
    ::CEGUI::RefCounted< CEGUI::BoundSlot > default_subscribeScriptedEvent( ::CEGUI::String const & name, unsigned int group, ::CEGUI::String const & subscriber_name ) {
        return CEGUI::EventSet::subscribeScriptedEvent( boost::ref(name), group, boost::ref(subscriber_name) );
    }

    void transferChildSurfaces(  ){
        CEGUI::Window::transferChildSurfaces(  );
    }

    virtual void update( float elapsed ) {
        if( bp::override func_update = this->get_override( "update" ) )
            func_update( elapsed );
        else{
            this->CEGUI::Window::update( elapsed );
        }
    }
    
    void default_update( float elapsed ) {
        CEGUI::Window::update( elapsed );
    }

    void updateGeometryRenderSettings(  ){
        CEGUI::Window::updateGeometryRenderSettings(  );
    }

    virtual void updateSelf( float elapsed ){
        if( bp::override func_updateSelf = this->get_override( "updateSelf" ) )
            func_updateSelf( elapsed );
        else{
            this->CEGUI::Window::updateSelf( elapsed );
        }
    }
    
    virtual void default_updateSelf( float elapsed ){
        CEGUI::Window::updateSelf( elapsed );
    }

    virtual bool writeAutoChildWindowXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        if( bp::override func_writeAutoChildWindowXML = this->get_override( "writeAutoChildWindowXML" ) )
            return func_writeAutoChildWindowXML( boost::ref(xml_stream) );
        else{
            return this->CEGUI::Window::writeAutoChildWindowXML( boost::ref(xml_stream) );
        }
    }
    
    virtual bool default_writeAutoChildWindowXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        return CEGUI::Window::writeAutoChildWindowXML( boost::ref(xml_stream) );
    }

    virtual int writeChildWindowsXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        if( bp::override func_writeChildWindowsXML = this->get_override( "writeChildWindowsXML" ) )
            return func_writeChildWindowsXML( boost::ref(xml_stream) );
        else{
            return this->CEGUI::Window::writeChildWindowsXML( boost::ref(xml_stream) );
        }
    }
    
    virtual int default_writeChildWindowsXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        return CEGUI::Window::writeChildWindowsXML( boost::ref(xml_stream) );
    }

    virtual int writePropertiesXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        if( bp::override func_writePropertiesXML = this->get_override( "writePropertiesXML" ) )
            return func_writePropertiesXML( boost::ref(xml_stream) );
        else{
            return this->CEGUI::Window::writePropertiesXML( boost::ref(xml_stream) );
        }
    }
    
    virtual int default_writePropertiesXML( ::CEGUI::XMLSerializer & xml_stream ) const {
        return CEGUI::Window::writePropertiesXML( boost::ref(xml_stream) );
    }

    virtual void writeXMLToStream( ::CEGUI::XMLSerializer & xml_stream ) const  {
        if( bp::override func_writeXMLToStream = this->get_override( "writeXMLToStream" ) )
            func_writeXMLToStream( boost::ref(xml_stream) );
        else{
            this->CEGUI::Window::writeXMLToStream( boost::ref(xml_stream) );
        }
    }
    
    void default_writeXMLToStream( ::CEGUI::XMLSerializer & xml_stream ) const  {
        CEGUI::Window::writeXMLToStream( boost::ref(xml_stream) );
    }

};

void register_Scrollbar_class(){

    { //::CEGUI::Scrollbar
        typedef bp::class_< Scrollbar_wrapper, bp::bases< CEGUI::Window >, boost::noncopyable > Scrollbar_exposer_t;
        Scrollbar_exposer_t Scrollbar_exposer = Scrollbar_exposer_t( "Scrollbar", "*!\n\
        \n\
            Base scroll bar class.\n\
        \n\
            This base class for scroll bars does not have any idea of direction - a\n\
            derived class would add whatever meaning is appropriate according to what\n\
            that derived class represents to the user.\n\
        *\n", bp::init< CEGUI::String const &, CEGUI::String const & >(( bp::arg("type"), bp::arg("name") )) );
        bp::scope Scrollbar_scope( Scrollbar_exposer );
        { //::CEGUI::Scrollbar::banPropertiesForAutoWindow
        
            typedef void ( Scrollbar_wrapper::*banPropertiesForAutoWindow_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "banPropertiesForAutoWindow"
                , banPropertiesForAutoWindow_function_type( &Scrollbar_wrapper::default_banPropertiesForAutoWindow )
                , "base class overrides\n" );
        
        }
        { //::CEGUI::Scrollbar::getAdjustDirectionFromPoint
        
            typedef float ( Scrollbar_wrapper::*getAdjustDirectionFromPoint_function_type )( ::CEGUI::Vector2f const & ) const;
            
            Scrollbar_exposer.def( 
                "getAdjustDirectionFromPoint"
                , getAdjustDirectionFromPoint_function_type( &Scrollbar_wrapper::getAdjustDirectionFromPoint )
                , ( bp::arg("pt") )
                , "*!\n\
                \n\
                    Given window location  pt, return a value indicating what change\n\
                    should be made to the scroll bar.\n\
            \n\
                @param pt\n\
                    Point object describing a pixel position in window space.\n\
            \n\
                @return\n\
                    - -1 to indicate scroll bar position should be moved to a lower value.\n\
                    -  0 to indicate scroll bar position should not be changed.\n\
                    - +1 to indicate scroll bar position should be moved to a higher value.\n\
                *\n" );
        
        }
        { //::CEGUI::Scrollbar::getDecreaseButton
        
            typedef ::CEGUI::PushButton * ( ::CEGUI::Scrollbar::*getDecreaseButton_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getDecreaseButton"
                , getDecreaseButton_function_type( &::CEGUI::Scrollbar::getDecreaseButton )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
                \n\
                    Return a pointer to the 'decrease' PushButton component widget for this\n\
                    Scrollbar.\n\
            \n\
                @return\n\
                    Pointer to a PushButton object.\n\
            \n\
                @exception UnknownObjectException\n\
                    Thrown if the 'decrease' PushButton component does not exist.\n\
                *\n" );
        
        }
        { //::CEGUI::Scrollbar::getDocumentSize
        
            typedef float ( ::CEGUI::Scrollbar::*getDocumentSize_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getDocumentSize"
                , getDocumentSize_function_type( &::CEGUI::Scrollbar::getDocumentSize )
                , "*!\n\
                \n\
                    Return the size of the document or data.\n\
            \n\
                    The document size should be thought of as the total size of the data\n\
                    that is being scrolled through (the number of lines in a text file for\n\
                    example).\n\
            \n\
                \note\n\
                    The returned value has no meaning within the Gui system, it is left up\n\
                    to the application to assign appropriate values for the application\n\
                    specific use of the scroll bar.\n\
            \n\
                @return\n\
                    float value specifying the currently set document size.\n\
                *\n" );
        
        }
        { //::CEGUI::Scrollbar::getIncreaseButton
        
            typedef ::CEGUI::PushButton * ( ::CEGUI::Scrollbar::*getIncreaseButton_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getIncreaseButton"
                , getIncreaseButton_function_type( &::CEGUI::Scrollbar::getIncreaseButton )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
                \n\
                    Return a pointer to the 'increase' PushButtoncomponent widget for this\n\
                    Scrollbar.\n\
            \n\
                @return\n\
                    Pointer to a PushButton object.\n\
            \n\
                @exception UnknownObjectException\n\
                    Thrown if the increase PushButton component does not exist.\n\
                *\n" );
        
        }
        { //::CEGUI::Scrollbar::getMaxScrollPosition
        
            typedef float ( Scrollbar_wrapper::*getMaxScrollPosition_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getMaxScrollPosition"
                , getMaxScrollPosition_function_type( &Scrollbar_wrapper::getMaxScrollPosition )
                , "! return the max allowable scroll position value\n" );
        
        }
        { //::CEGUI::Scrollbar::getOverlapSize
        
            typedef float ( ::CEGUI::Scrollbar::*getOverlapSize_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getOverlapSize"
                , getOverlapSize_function_type( &::CEGUI::Scrollbar::getOverlapSize )
                , "*!\n\
                \n\
                    Return the overlap size for this scroll bar.\n\
            \n\
                    The overlap size is the amount of data from the end of a 'page' that\n\
                    will remain visible when the position is moved by a page.  This is\n\
                    usually used so that the user keeps some context of where they were\n\
                    within the document's data when jumping a page at a time.\n\
            \n\
                \note\n\
                    The returned value has no meaning within the Gui system, it is left up\n\
                    to the application to assign appropriate values for the application\n\
                    specific use of the scroll bar.\n\
            \n\
                @return\n\
                    float value specifying the currently set overlap size.\n\
                *\n" );
        
        }
        { //::CEGUI::Scrollbar::getPageSize
        
            typedef float ( ::CEGUI::Scrollbar::*getPageSize_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getPageSize"
                , getPageSize_function_type( &::CEGUI::Scrollbar::getPageSize )
                , "*!\n\
                \n\
                    Return the page size for this scroll bar.\n\
            \n\
                    The page size is typically the amount of data that can be displayed at\n\
                    one time.  This value is also used when calculating the amount the\n\
                    position will change when you click either side of the scroll bar\n\
                    thumb, the amount the position changes will is (pageSize - overlapSize).\n\
            \n\
                \note\n\
                    The returned value has no meaning within the Gui system, it is left up\n\
                    to the application to assign appropriate values for the application\n\
                    specific use of the scroll bar.\n\
            \n\
                @return\n\
                    float value specifying the currently set page size.\n\
                *\n" );
        
        }
        { //::CEGUI::Scrollbar::getScrollPosition
        
            typedef float ( ::CEGUI::Scrollbar::*getScrollPosition_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getScrollPosition"
                , getScrollPosition_function_type( &::CEGUI::Scrollbar::getScrollPosition )
                , "*!\n\
                \n\
                    Return the current position of scroll bar within the document.\n\
            \n\
                    The range of the scroll bar is from 0 to the size of the document minus\n\
                    the size of a page (0 <= position <= (documentSize - pageSize)).\n\
            \n\
                \note\n\
                    The returned value has no meaning within the Gui system, it is left up\n\
                    to the application to assign appropriate values for the application\n\
                    specific use of the scroll bar.\n\
            \n\
                @return\n\
                    float value specifying the current position of the scroll bar within its\n\
                    document.\n\
                *\n" );
        
        }
        { //::CEGUI::Scrollbar::getStepSize
        
            typedef float ( ::CEGUI::Scrollbar::*getStepSize_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getStepSize"
                , getStepSize_function_type( &::CEGUI::Scrollbar::getStepSize )
                , "*!\n\
                \n\
                    Return the step size for this scroll bar.\n\
            \n\
                    The step size is typically a single unit of data that can be displayed,\n\
                    this is the amount the position will change when you click either of\n\
                    the arrow buttons on the scroll bar.  (this could be 1 for a single\n\
                    line of text, for example).\n\
            \n\
                \note\n\
                    The returned value has no meaning within the Gui system, it is left up\n\
                    to the application to assign appropriate values for the application\n\
                    specific use of the scroll bar.\n\
            \n\
                @return\n\
                    float value specifying the currently set step size.\n\
                *\n" );
        
        }
        { //::CEGUI::Scrollbar::getThumb
        
            typedef ::CEGUI::Thumb * ( ::CEGUI::Scrollbar::*getThumb_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getThumb"
                , getThumb_function_type( &::CEGUI::Scrollbar::getThumb )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
                \n\
                    Return a pointer to the Thumb component widget for this Scrollbar.\n\
            \n\
                @return\n\
                    Pointer to a Thumb object.\n\
            \n\
                @exception UnknownObjectException\n\
                    Thrown if the Thumb component does not exist.\n\
                *\n" );
        
        }
        { //::CEGUI::Scrollbar::getUnitIntervalScrollPosition
        
            typedef float ( ::CEGUI::Scrollbar::*getUnitIntervalScrollPosition_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getUnitIntervalScrollPosition"
                , getUnitIntervalScrollPosition_function_type( &::CEGUI::Scrollbar::getUnitIntervalScrollPosition )
                , "! return the current scroll position as a value in the interval [0, 1]\n" );
        
        }
        { //::CEGUI::Scrollbar::getValueFromThumb
        
            typedef float ( Scrollbar_wrapper::*getValueFromThumb_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getValueFromThumb"
                , getValueFromThumb_function_type( &Scrollbar_wrapper::getValueFromThumb )
                , "*!\n\
                \n\
                    return value that best represents current scroll bar position given the\n\
                    current location of the thumb.\n\
            \n\
                @return\n\
                    float value that, given the thumb widget position, best represents the\n\
                    current position for the scroll bar.\n\
                *\n" );
        
        }
        { //::CEGUI::Scrollbar::handleDecreaseClicked
        
            typedef bool ( Scrollbar_wrapper::*handleDecreaseClicked_function_type )( ::CEGUI::EventArgs const & ) ;
            
            Scrollbar_exposer.def( 
                "handleDecreaseClicked"
                , handleDecreaseClicked_function_type( &Scrollbar_wrapper::handleDecreaseClicked )
                , ( bp::arg("e") )
                , "! handler function for when the decrease button is clicked.\n" );
        
        }
        { //::CEGUI::Scrollbar::handleIncreaseClicked
        
            typedef bool ( Scrollbar_wrapper::*handleIncreaseClicked_function_type )( ::CEGUI::EventArgs const & ) ;
            
            Scrollbar_exposer.def( 
                "handleIncreaseClicked"
                , handleIncreaseClicked_function_type( &Scrollbar_wrapper::handleIncreaseClicked )
                , ( bp::arg("e") )
                , "! handler function for when the increase button is clicked.\n" );
        
        }
        { //::CEGUI::Scrollbar::handleThumbMoved
        
            typedef bool ( Scrollbar_wrapper::*handleThumbMoved_function_type )( ::CEGUI::EventArgs const & ) ;
            
            Scrollbar_exposer.def( 
                "handleThumbMoved"
                , handleThumbMoved_function_type( &Scrollbar_wrapper::handleThumbMoved )
                , ( bp::arg("e") )
                , "! handler function for when thumb moves.\n" );
        
        }
        { //::CEGUI::Scrollbar::handleThumbTrackEnded
        
            typedef bool ( Scrollbar_wrapper::*handleThumbTrackEnded_function_type )( ::CEGUI::EventArgs const & ) ;
            
            Scrollbar_exposer.def( 
                "handleThumbTrackEnded"
                , handleThumbTrackEnded_function_type( &Scrollbar_wrapper::handleThumbTrackEnded )
                , ( bp::arg("e") )
                , "! handler function for when thumb tracking begins\n" );
        
        }
        { //::CEGUI::Scrollbar::handleThumbTrackStarted
        
            typedef bool ( Scrollbar_wrapper::*handleThumbTrackStarted_function_type )( ::CEGUI::EventArgs const & ) ;
            
            Scrollbar_exposer.def( 
                "handleThumbTrackStarted"
                , handleThumbTrackStarted_function_type( &Scrollbar_wrapper::handleThumbTrackStarted )
                , ( bp::arg("e") )
                , "! handler function for when thumb tracking begins\n" );
        
        }
        { //::CEGUI::Scrollbar::initialiseComponents
        
            typedef void ( ::CEGUI::Scrollbar::*initialiseComponents_function_type )(  ) ;
            typedef void ( Scrollbar_wrapper::*default_initialiseComponents_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "initialiseComponents"
                , initialiseComponents_function_type(&::CEGUI::Scrollbar::initialiseComponents)
                , default_initialiseComponents_function_type(&Scrollbar_wrapper::default_initialiseComponents) );
        
        }
        { //::CEGUI::Scrollbar::isAtEnd
        
            typedef bool ( Scrollbar_wrapper::*isAtEnd_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "isAtEnd"
                , isAtEnd_function_type( &Scrollbar_wrapper::isAtEnd )
                , "! return whether the current scroll position is at the end of the range.\n" );
        
        }
        { //::CEGUI::Scrollbar::isEndLockEnabled
        
            typedef bool ( ::CEGUI::Scrollbar::*isEndLockEnabled_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "isEndLockEnabled"
                , isEndLockEnabled_function_type( &::CEGUI::Scrollbar::isEndLockEnabled )
                , "*!\n\
                \n\
                    Returns whether the 'end lock'mode for the scrollbar is enabled.\n\
            \n\
                    When enabled, and the current position of the scrollbar is at the end of\n\
                    it's travel, the end lock mode of the scrollbar will automatically\n\
                    update the scrollbar position when the document andor page size change\n\
                    in order that the scroll position will remain at the end of it's travel.\n\
                    This can be used to implement auto-scrolling in certain other widget\n\
                    types.\n\
            \n\
                @return\n\
                    - true to indicate that the end lock mode is enabled.\n\
                    - false to indicate that the end lock mode is disabled.\n\
                *\n" );
        
        }
        { //::CEGUI::Scrollbar::onMouseButtonDown
        
            typedef void ( Scrollbar_wrapper::*onMouseButtonDown_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onMouseButtonDown"
                , onMouseButtonDown_function_type( &Scrollbar_wrapper::default_onMouseButtonDown )
                , ( bp::arg("e") )
                , "Overridden event handlers\n" );
        
        }
        { //::CEGUI::Scrollbar::onMouseWheel
        
            typedef void ( Scrollbar_wrapper::*onMouseWheel_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onMouseWheel"
                , onMouseWheel_function_type( &Scrollbar_wrapper::default_onMouseWheel )
                , ( bp::arg("e") )
                , "Overridden event handlers\n" );
        
        }
        { //::CEGUI::Scrollbar::onScrollConfigChanged
        
            typedef void ( Scrollbar_wrapper::*onScrollConfigChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onScrollConfigChanged"
                , onScrollConfigChanged_function_type( &Scrollbar_wrapper::default_onScrollConfigChanged )
                , ( bp::arg("e") )
                , "! Handler triggered when the scroll bar data configuration changes\n" );
        
        }
        { //::CEGUI::Scrollbar::onScrollPositionChanged
        
            typedef void ( Scrollbar_wrapper::*onScrollPositionChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onScrollPositionChanged"
                , onScrollPositionChanged_function_type( &Scrollbar_wrapper::default_onScrollPositionChanged )
                , ( bp::arg("e") )
                , "New event handlers for slider widget\n\
            ! Handler triggered when the scroll position changes\n" );
        
        }
        { //::CEGUI::Scrollbar::onThumbTrackEnded
        
            typedef void ( Scrollbar_wrapper::*onThumbTrackEnded_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onThumbTrackEnded"
                , onThumbTrackEnded_function_type( &Scrollbar_wrapper::default_onThumbTrackEnded )
                , ( bp::arg("e") )
                , "! Handler triggered when the scroll bar thumb is released\n" );
        
        }
        { //::CEGUI::Scrollbar::onThumbTrackStarted
        
            typedef void ( Scrollbar_wrapper::*onThumbTrackStarted_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onThumbTrackStarted"
                , onThumbTrackStarted_function_type( &Scrollbar_wrapper::default_onThumbTrackStarted )
                , ( bp::arg("e") )
                , "! Handler triggered when the user begins to drag the scroll bar thumb.\n" );
        
        }
        { //::CEGUI::Scrollbar::scrollBackwardsByPage
        
            typedef void ( ::CEGUI::Scrollbar::*scrollBackwardsByPage_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "scrollBackwardsByPage"
                , scrollBackwardsByPage_function_type( &::CEGUI::Scrollbar::scrollBackwardsByPage )
                , "! move scroll position forwards by a page (uses appropriate overlap)\n\
            ! move scroll position backwards by a page (uses appropriate overlap)\n" );
        
        }
        { //::CEGUI::Scrollbar::scrollBackwardsByStep
        
            typedef void ( ::CEGUI::Scrollbar::*scrollBackwardsByStep_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "scrollBackwardsByStep"
                , scrollBackwardsByStep_function_type( &::CEGUI::Scrollbar::scrollBackwardsByStep )
                , "! move scroll position forwards by the current step size\n\
            ! move scroll position backwards by the current step size\n" );
        
        }
        { //::CEGUI::Scrollbar::scrollForwardsByPage
        
            typedef void ( ::CEGUI::Scrollbar::*scrollForwardsByPage_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "scrollForwardsByPage"
                , scrollForwardsByPage_function_type( &::CEGUI::Scrollbar::scrollForwardsByPage )
                , "! move scroll position forwards by a page (uses appropriate overlap)\n" );
        
        }
        { //::CEGUI::Scrollbar::scrollForwardsByStep
        
            typedef void ( ::CEGUI::Scrollbar::*scrollForwardsByStep_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "scrollForwardsByStep"
                , scrollForwardsByStep_function_type( &::CEGUI::Scrollbar::scrollForwardsByStep )
                , "! move scroll position forwards by the current step size\n" );
        
        }
        { //::CEGUI::Scrollbar::setConfig
        
            typedef void ( ::CEGUI::Scrollbar::*setConfig_function_type )( float const * const,float const * const,float const * const,float const * const,float const * const ) ;
            
            Scrollbar_exposer.def( 
                "setConfig"
                , setConfig_function_type( &::CEGUI::Scrollbar::setConfig )
                , ( bp::arg("document_size"), bp::arg("page_size"), bp::arg("step_size"), bp::arg("overlap_size"), bp::arg("position") ) );
        
        }
        { //::CEGUI::Scrollbar::setDocumentSize
        
            typedef void ( ::CEGUI::Scrollbar::*setDocumentSize_function_type )( float ) ;
            
            Scrollbar_exposer.def( 
                "setDocumentSize"
                , setDocumentSize_function_type( &::CEGUI::Scrollbar::setDocumentSize )
                , ( bp::arg("document_size") )
                , "*!\n\
                \n\
                    Set the size of the document or data.\n\
            \n\
                    The document size should be thought of as the total size of the data\n\
                    that is being scrolled through (the number of lines in a text file for\n\
                    example).\n\
            \n\
                \note\n\
                    The value set has no meaning within the Gui system, it is left up to\n\
                    the application to assign appropriate values for the application\n\
                    specific use of the scroll bar.\n\
            \n\
                @param document_size\n\
                    float value specifying the document size.\n\
                *\n" );
        
        }
        { //::CEGUI::Scrollbar::setEndLockEnabled
        
            typedef void ( ::CEGUI::Scrollbar::*setEndLockEnabled_function_type )( bool const ) ;
            
            Scrollbar_exposer.def( 
                "setEndLockEnabled"
                , setEndLockEnabled_function_type( &::CEGUI::Scrollbar::setEndLockEnabled )
                , ( bp::arg("enabled") )
                , "*!\n\
                \n\
                    Enable or disable the 'end lock' mode for the scrollbar.\n\
            \n\
                    When enabled and the current position of the scrollbar is at the end of\n\
                    it's travel, the end lock mode of the scrollbar will automatically\n\
                    update the position when the document andor page size change in order\n\
                    that the scroll position will remain at the end of it's travel.  This\n\
                    can be used to implement auto-scrolling in certain other widget types.\n\
            \n\
                @param enabled\n\
                    - true to indicate that end lock mode should be enabled.\n\
                    - false to indicate that end lock mode should be disabled.\n\
                *\n" );
        
        }
        { //::CEGUI::Scrollbar::setOverlapSize
        
            typedef void ( ::CEGUI::Scrollbar::*setOverlapSize_function_type )( float ) ;
            
            Scrollbar_exposer.def( 
                "setOverlapSize"
                , setOverlapSize_function_type( &::CEGUI::Scrollbar::setOverlapSize )
                , ( bp::arg("overlap_size") )
                , "*!\n\
                \n\
                    Set the overlap size for this scroll bar.\n\
            \n\
                    The overlap size is the amount of data from the end of a 'page' that\n\
                    will remain visible when the position is moved by a page.  This is\n\
                    usually used so that the user keeps some context of where they were\n\
                    within the document's data when jumping a page at a time.\n\
            \n\
                \note\n\
                    The value set has no meaning within the Gui system, it is left up to the\n\
                    application to assign appropriate values for the application specific\n\
                    use of the scroll bar.\n\
            \n\
                @param overlap_size\n\
                    float value specifying the overlap size.\n\
                *\n" );
        
        }
        { //::CEGUI::Scrollbar::setPageSize
        
            typedef void ( ::CEGUI::Scrollbar::*setPageSize_function_type )( float ) ;
            
            Scrollbar_exposer.def( 
                "setPageSize"
                , setPageSize_function_type( &::CEGUI::Scrollbar::setPageSize )
                , ( bp::arg("page_size") )
                , "*!\n\
                \n\
                    Set the page size for this scroll bar.\n\
            \n\
                    The page size is typically the amount of data that can be displayed at\n\
                    one time.  This value is also used when calculating the amount the\n\
                    position will change when you click either side of the scroll bar\n\
                    thumb, the amount the position changes will is (pageSize - overlapSize).\n\
            \n\
                \note\n\
                    The value set has no meaning within the Gui system, it is left up to the\n\
                    application to assign appropriate values for the application specific\n\
                    use of the scroll bar.\n\
            \n\
                @param page_size\n\
                    float value specifying the page size.\n\
                *\n" );
        
        }
        { //::CEGUI::Scrollbar::setScrollPosition
        
            typedef void ( ::CEGUI::Scrollbar::*setScrollPosition_function_type )( float ) ;
            
            Scrollbar_exposer.def( 
                "setScrollPosition"
                , setScrollPosition_function_type( &::CEGUI::Scrollbar::setScrollPosition )
                , ( bp::arg("position") )
                , "*!\n\
                \n\
                    Set the current position of scroll bar within the document.\n\
            \n\
                    The range of the scroll bar is from 0 to the size of the document minus\n\
                    the size of a page (0 <= position <= (documentSize - pageSize)), any\n\
                    attempt to set the position outside this range will be adjusted so that\n\
                    it falls within the legal range.\n\
            \n\
                \note\n\
                    The returned value has no meaning within the Gui system, it is left up\n\
                    to the application to assign appropriate values for the application\n\
                    specific use of the scroll bar.\n\
            \n\
                @param position\n\
                    float value specifying the position of the scroll bar within its\n\
                    document.\n\
                *\n" );
        
        }
        { //::CEGUI::Scrollbar::setScrollPosition_impl
        
            typedef bool ( Scrollbar_wrapper::*setScrollPosition_impl_function_type )( float const ) ;
            
            Scrollbar_exposer.def( 
                "setScrollPosition_impl"
                , setScrollPosition_impl_function_type( &Scrollbar_wrapper::setScrollPosition_impl )
                , ( bp::arg("position") )
                , "** implementation func that updates scroll position value, returns true if\n\
             * value was changed.  NB: Fires no events and does no other updates.\n\
             *\n" );
        
        }
        { //::CEGUI::Scrollbar::setStepSize
        
            typedef void ( ::CEGUI::Scrollbar::*setStepSize_function_type )( float ) ;
            
            Scrollbar_exposer.def( 
                "setStepSize"
                , setStepSize_function_type( &::CEGUI::Scrollbar::setStepSize )
                , ( bp::arg("step_size") )
                , "*!\n\
                \n\
                    Set the step size for this scroll bar.\n\
            \n\
                    The step size is typically a single unit of data that can be displayed,\n\
                    this is the amount the position will change when you click either of the\n\
                    arrow buttons on the scroll bar.  (this could be 1 for a single line of\n\
                    text, for example).\n\
            \n\
                \note\n\
                    The value set has no meaning within the Gui system, it is left up to the\n\
                    application to assign appropriate values for the application specific\n\
                    use of the scroll bar.\n\
            \n\
                @param step_size\n\
                    float value specifying the step size.\n\
                *\n" );
        
        }
        { //::CEGUI::Scrollbar::setUnitIntervalScrollPosition
        
            typedef void ( ::CEGUI::Scrollbar::*setUnitIntervalScrollPosition_function_type )( float ) ;
            
            Scrollbar_exposer.def( 
                "setUnitIntervalScrollPosition"
                , setUnitIntervalScrollPosition_function_type( &::CEGUI::Scrollbar::setUnitIntervalScrollPosition )
                , ( bp::arg("position") )
                , "! return the current scroll position as a value in the interval [0, 1]\n\
            ! set the current scroll position as a value in the interval [0, 1]\n" );
        
        }
        { //::CEGUI::Scrollbar::updateThumb
        
            typedef void ( Scrollbar_wrapper::*updateThumb_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "updateThumb"
                , updateThumb_function_type( &Scrollbar_wrapper::updateThumb )
                , "*!\n\
            \n\
                update the size and location of the thumb to properly represent the\n\
                current state of the scroll bar\n\
            *\n" );
        
        }
        { //::CEGUI::Scrollbar::validateWindowRenderer
        
            typedef bool ( Scrollbar_wrapper::*validateWindowRenderer_function_type )( ::CEGUI::WindowRenderer const * ) const;
            
            Scrollbar_exposer.def( 
                "validateWindowRenderer"
                , validateWindowRenderer_function_type( &Scrollbar_wrapper::default_validateWindowRenderer )
                , ( bp::arg("renderer") )
                , "! validate window renderer\n" );
        
        }
        Scrollbar_exposer.add_static_property( "DecreaseButtonName"
                        , bp::make_getter( &CEGUI::Scrollbar::DecreaseButtonName
                                , bp::return_value_policy< bp::return_by_value >() ) );
        Scrollbar_exposer.add_static_property( "EventScrollConfigChanged"
                        , bp::make_getter( &CEGUI::Scrollbar::EventScrollConfigChanged
                                , bp::return_value_policy< bp::return_by_value >() ) );
        Scrollbar_exposer.add_static_property( "EventScrollPositionChanged"
                        , bp::make_getter( &CEGUI::Scrollbar::EventScrollPositionChanged
                                , bp::return_value_policy< bp::return_by_value >() ) );
        Scrollbar_exposer.add_static_property( "EventThumbTrackEnded"
                        , bp::make_getter( &CEGUI::Scrollbar::EventThumbTrackEnded
                                , bp::return_value_policy< bp::return_by_value >() ) );
        Scrollbar_exposer.add_static_property( "EventThumbTrackStarted"
                        , bp::make_getter( &CEGUI::Scrollbar::EventThumbTrackStarted
                                , bp::return_value_policy< bp::return_by_value >() ) );
        Scrollbar_exposer.add_static_property( "IncreaseButtonName"
                        , bp::make_getter( &CEGUI::Scrollbar::IncreaseButtonName
                                , bp::return_value_policy< bp::return_by_value >() ) );
        Scrollbar_exposer.add_static_property( "ThumbName"
                        , bp::make_getter( &CEGUI::Scrollbar::ThumbName
                                , bp::return_value_policy< bp::return_by_value >() ) );
        { //::CEGUI::Window::addChild_impl
        
            typedef void ( Scrollbar_wrapper::*addChild_impl_function_type )( ::CEGUI::Element * ) ;
            
            Scrollbar_exposer.def( 
                "addChild_impl"
                , addChild_impl_function_type( &Scrollbar_wrapper::default_addChild_impl )
                , ( bp::arg("element") )
                , "*!\n\
            opydoc Element.addChild_impl\n\
            *\n" );
        
        }
        { //::CEGUI::Element::addElementProperties
        
            typedef void ( Scrollbar_wrapper::*addElementProperties_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "addElementProperties"
                , addElementProperties_function_type( &Scrollbar_wrapper::addElementProperties )
                , "*!\n\
            \n\
                Add standard CEGUI.Element properties.\n\
            *\n" );
        
        }
        { //::CEGUI::NamedElement::addNamedElementProperties
        
            typedef void ( Scrollbar_wrapper::*addNamedElementProperties_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "addNamedElementProperties"
                , addNamedElementProperties_function_type( &Scrollbar_wrapper::addNamedElementProperties )
                , "*!\n\
             Add standard CEGUI.NamedElement properties.\n\
            *\n" );
        
        }
        { //::CEGUI::Window::addWindowProperties
        
            typedef void ( Scrollbar_wrapper::*addWindowProperties_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "addWindowProperties"
                , addWindowProperties_function_type( &Scrollbar_wrapper::addWindowProperties )
                , "*!\n\
            \n\
                Add standard CEGUI.Window properties.\n\
            *\n" );
        
        }
        { //::CEGUI::Window::addWindowToDrawList
        
            typedef void ( Scrollbar_wrapper::*addWindowToDrawList_function_type )( ::CEGUI::Window &,bool ) ;
            
            Scrollbar_exposer.def( 
                "addWindowToDrawList"
                , addWindowToDrawList_function_type( &Scrollbar_wrapper::addWindowToDrawList )
                , ( bp::arg("wnd"), bp::arg("at_back")=(bool)(false) )
                , "*!\n\
                \n\
                    Add the given window to the drawing list at an appropriate position for\n\
                    it's settings and the required direction.  Basically, when  at_back\n\
                    is false, the window will appear in front of all other windows with the\n\
                    same 'always on top' setting.  When  at_back is true, the window will\n\
                    appear behind all other windows wih the same 'always on top' setting.\n\
            \n\
                @param wnd\n\
                    Window object to be added to the drawing list.\n\
            \n\
                @param at_back\n\
                    Indicates whether the window should be placed at the back of other\n\
                    windows in the same group. If this is false, the window is placed in\n\
                    front of other windows in the group.\n\
            \n\
                @return\n\
                    Nothing.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::allocateRenderingWindow
        
            typedef void ( Scrollbar_wrapper::*allocateRenderingWindow_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "allocateRenderingWindow"
                , allocateRenderingWindow_function_type( &Scrollbar_wrapper::allocateRenderingWindow )
                , "! helper to create and setup the auto RenderingWindow surface\n" );
        
        }
        { //::CEGUI::Window::beginInitialisation
        
            typedef void ( ::CEGUI::Window::*beginInitialisation_function_type )(  ) ;
            typedef void ( Scrollbar_wrapper::*default_beginInitialisation_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "beginInitialisation"
                , beginInitialisation_function_type(&::CEGUI::Window::beginInitialisation)
                , default_beginInitialisation_function_type(&Scrollbar_wrapper::default_beginInitialisation) );
        
        }
        { //::CEGUI::Window::bufferGeometry
        
            typedef void ( Scrollbar_wrapper::*bufferGeometry_function_type )( ::CEGUI::RenderingContext const & ) ;
            
            Scrollbar_exposer.def( 
                "bufferGeometry"
                , bufferGeometry_function_type( &Scrollbar_wrapper::bufferGeometry )
                , ( bp::arg("ctx") )
                , "*!\n\
                \n\
                    Perform drawing operations concerned with generating and buffering\n\
                    window geometry.\n\
            \n\
                \note\n\
                    This function is a sub-function of drawSelf; it is provided to make it\n\
                    easier to override drawSelf without needing to duplicate large sections\n\
                    of the code from the default implementation.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::cleanupChildren
        
            typedef void ( Scrollbar_wrapper::*cleanupChildren_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "cleanupChildren"
                , cleanupChildren_function_type( &Scrollbar_wrapper::default_cleanupChildren )
                , "*!\n\
            \n\
                Cleanup child windows\n\
            *\n" );
        
        }
        { //::CEGUI::Window::cloneChildWidgetsTo
        
            typedef void ( ::CEGUI::Window::*cloneChildWidgetsTo_function_type )( ::CEGUI::Window & ) const;
            typedef void ( Scrollbar_wrapper::*default_cloneChildWidgetsTo_function_type )( ::CEGUI::Window & ) const;
            
            Scrollbar_exposer.def( 
                "cloneChildWidgetsTo"
                , cloneChildWidgetsTo_function_type(&::CEGUI::Window::cloneChildWidgetsTo)
                , default_cloneChildWidgetsTo_function_type(&Scrollbar_wrapper::default_cloneChildWidgetsTo)
                , ( bp::arg("target") ) );
        
        }
        { //::CEGUI::Window::clonePropertiesTo
        
            typedef void ( ::CEGUI::Window::*clonePropertiesTo_function_type )( ::CEGUI::Window & ) const;
            typedef void ( Scrollbar_wrapper::*default_clonePropertiesTo_function_type )( ::CEGUI::Window & ) const;
            
            Scrollbar_exposer.def( 
                "clonePropertiesTo"
                , clonePropertiesTo_function_type(&::CEGUI::Window::clonePropertiesTo)
                , default_clonePropertiesTo_function_type(&Scrollbar_wrapper::default_clonePropertiesTo)
                , ( bp::arg("target") ) );
        
        }
        { //::CEGUI::Window::destroy
        
            typedef void ( ::CEGUI::Window::*destroy_function_type )(  ) ;
            typedef void ( Scrollbar_wrapper::*default_destroy_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "destroy"
                , destroy_function_type(&::CEGUI::Window::destroy)
                , default_destroy_function_type(&Scrollbar_wrapper::default_destroy) );
        
        }
        { //::CEGUI::Window::drawSelf
        
            typedef void ( Scrollbar_wrapper::*drawSelf_function_type )( ::CEGUI::RenderingContext const & ) ;
            
            Scrollbar_exposer.def( 
                "drawSelf"
                , drawSelf_function_type( &Scrollbar_wrapper::default_drawSelf )
                , ( bp::arg("ctx") )
                , "*!\n\
                \n\
                    Perform the actual rendering for this Window.\n\
            \n\
                @param ctx\n\
                    RenderingContext holding the details of the RenderingSurface to be\n\
                    used for the Window rendering operations.\n\
            \n\
                @return\n\
                    Nothing\n\
                *\n" );
        
        }
        { //::CEGUI::Window::endInitialisation
        
            typedef void ( ::CEGUI::Window::*endInitialisation_function_type )(  ) ;
            typedef void ( Scrollbar_wrapper::*default_endInitialisation_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "endInitialisation"
                , endInitialisation_function_type(&::CEGUI::Window::endInitialisation)
                , default_endInitialisation_function_type(&Scrollbar_wrapper::default_endInitialisation) );
        
        }
        { //::CEGUI::Element::fireAreaChangeEvents
        
            typedef void ( Scrollbar_wrapper::*fireAreaChangeEvents_function_type )( bool const,bool const ) ;
            
            Scrollbar_exposer.def( 
                "fireAreaChangeEvents"
                , fireAreaChangeEvents_function_type( &Scrollbar_wrapper::fireAreaChangeEvents )
                , ( bp::arg("moved"), bp::arg("sized") )
                , "! helper to fire events based on changes to area rect\n" );
        
        }
        { //::CEGUI::EventSet::fireEvent
        
            typedef void ( ::CEGUI::EventSet::*fireEvent_function_type )( ::CEGUI::String const &,::CEGUI::EventArgs &,::CEGUI::String const & ) ;
            typedef void ( Scrollbar_wrapper::*default_fireEvent_function_type )( ::CEGUI::String const &,::CEGUI::EventArgs &,::CEGUI::String const & ) ;
            
            Scrollbar_exposer.def( 
                "fireEvent"
                , fireEvent_function_type(&::CEGUI::EventSet::fireEvent)
                , default_fireEvent_function_type(&Scrollbar_wrapper::default_fireEvent)
                , ( bp::arg("name"), bp::arg("args"), bp::arg("eventNamespace")="" ) );
        
        }
        { //::CEGUI::EventSet::fireEvent_impl
        
            typedef void ( Scrollbar_wrapper::*fireEvent_impl_function_type )( ::CEGUI::String const &,::CEGUI::EventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "fireEvent_impl"
                , fireEvent_impl_function_type( &Scrollbar_wrapper::fireEvent_impl )
                , ( bp::arg("name"), bp::arg("args") )
                , "! Implementation event firing member\n" );
        
        }
        { //::CEGUI::Window::generateAutoRepeatEvent
        
            typedef void ( Scrollbar_wrapper::*generateAutoRepeatEvent_function_type )( ::CEGUI::MouseButton ) ;
            
            Scrollbar_exposer.def( 
                "generateAutoRepeatEvent"
                , generateAutoRepeatEvent_function_type( &Scrollbar_wrapper::generateAutoRepeatEvent )
                , ( bp::arg("button") )
                , "*!\n\
            \n\
                Fires off a repeated mouse button down event for this window.\n\
            *\n" );
        
        }
        { //::CEGUI::NamedElement::getChildByNamePath_impl
        
            typedef ::CEGUI::NamedElement * ( Scrollbar_wrapper::*getChildByNamePath_impl_function_type )( ::CEGUI::String const & ) const;
            
            Scrollbar_exposer.def( 
                "getChildByNamePath_impl"
                , getChildByNamePath_impl_function_type( &Scrollbar_wrapper::default_getChildByNamePath_impl )
                , ( bp::arg("name_path") )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
             Retrieves a child at  name_path or 0 if none such exists\n\
            *\n" );
        
        }
        { //::CEGUI::NamedElement::getChildByNameRecursive_impl
        
            typedef ::CEGUI::NamedElement * ( Scrollbar_wrapper::*getChildByNameRecursive_impl_function_type )( ::CEGUI::String const & ) const;
            
            Scrollbar_exposer.def( 
                "getChildByNameRecursive_impl"
                , getChildByNameRecursive_impl_function_type( &Scrollbar_wrapper::default_getChildByNameRecursive_impl )
                , ( bp::arg("name") )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
             Finds a child by  name or 0 if none such exists\n\
            *\n" );
        
        }
        { //::CEGUI::Element::getClientChildContentArea
        
            typedef ::CEGUI::Element::CachedRectf const & ( ::CEGUI::Element::*getClientChildContentArea_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getClientChildContentArea"
                , getClientChildContentArea_function_type(&::CEGUI::Element::getClientChildContentArea)
                , bp::return_value_policy< bp::copy_const_reference >() );
        
        }
        { //::CEGUI::Window::getHitTestRect_impl
        
            typedef ::CEGUI::Rectf ( Scrollbar_wrapper::*getHitTestRect_impl_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getHitTestRect_impl"
                , getHitTestRect_impl_function_type( &Scrollbar_wrapper::default_getHitTestRect_impl )
                , "! Default implementation of function to return Window inner clipper area.\n\
            ! Default implementation of function to return Window hit-test area.\n" );
        
        }
        { //::CEGUI::Window::getInnerRectClipper_impl
        
            typedef ::CEGUI::Rectf ( Scrollbar_wrapper::*getInnerRectClipper_impl_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getInnerRectClipper_impl"
                , getInnerRectClipper_impl_function_type( &Scrollbar_wrapper::default_getInnerRectClipper_impl )
                , "! Default implementation of function to return Window outer clipper area.\n\
            ! Default implementation of function to return Window inner clipper area.\n" );
        
        }
        { //::CEGUI::Element::getNonClientChildContentArea
        
            typedef ::CEGUI::Element::CachedRectf const & ( ::CEGUI::Element::*getNonClientChildContentArea_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getNonClientChildContentArea"
                , getNonClientChildContentArea_function_type(&::CEGUI::Element::getNonClientChildContentArea)
                , bp::return_value_policy< bp::copy_const_reference >() );
        
        }
        { //::CEGUI::Window::getOuterRectClipper_impl
        
            typedef ::CEGUI::Rectf ( Scrollbar_wrapper::*getOuterRectClipper_impl_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getOuterRectClipper_impl"
                , getOuterRectClipper_impl_function_type( &Scrollbar_wrapper::default_getOuterRectClipper_impl )
                , "! Default implementation of function to return Window outer clipper area.\n" );
        
        }
        { //::CEGUI::Window::getParentElementClipIntersection
        
            typedef ::CEGUI::Rectf ( Scrollbar_wrapper::*getParentElementClipIntersection_function_type )( ::CEGUI::Rectf const & ) const;
            
            Scrollbar_exposer.def( 
                "getParentElementClipIntersection"
                , getParentElementClipIntersection_function_type( &Scrollbar_wrapper::getParentElementClipIntersection )
                , ( bp::arg("unclipped_area") )
                , "! helper function for calculating clipping rectangles.\n" );
        
        }
        { //::CEGUI::Window::getRenderedStringParser
        
            typedef ::CEGUI::RenderedStringParser & ( ::CEGUI::Window::*getRenderedStringParser_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getRenderedStringParser"
                , getRenderedStringParser_function_type(&::CEGUI::Window::getRenderedStringParser)
                , bp::return_value_policy< bp::reference_existing_object >() );
        
        }
        { //::CEGUI::Window::getRenderingContext_impl
        
            typedef void ( ::CEGUI::Window::*getRenderingContext_impl_function_type )( ::CEGUI::RenderingContext & ) const;
            typedef void ( Scrollbar_wrapper::*default_getRenderingContext_impl_function_type )( ::CEGUI::RenderingContext & ) const;
            
            Scrollbar_exposer.def( 
                "getRenderingContext_impl"
                , getRenderingContext_impl_function_type(&::CEGUI::Window::getRenderingContext_impl)
                , default_getRenderingContext_impl_function_type(&Scrollbar_wrapper::default_getRenderingContext_impl)
                , ( bp::arg("ctx") ) );
        
        }
        { //::CEGUI::Window::getRootContainerSize
        
            typedef ::CEGUI::Sizef const & ( ::CEGUI::Window::*getRootContainerSize_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getRootContainerSize"
                , getRootContainerSize_function_type(&::CEGUI::Window::getRootContainerSize)
                , bp::return_value_policy< bp::copy_const_reference >() );
        
        }
        { //::CEGUI::EventSet::getScriptModule
        
            typedef ::CEGUI::ScriptModule * ( Scrollbar_wrapper::*getScriptModule_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "getScriptModule"
                , getScriptModule_function_type( &Scrollbar_wrapper::getScriptModule )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "! Implementation event firing member\n\
            ! Helper to return the script module pointer or throw.\n" );
        
        }
        { //::CEGUI::Window::getUnclippedInnerRect_impl
        
            typedef ::CEGUI::Rectf ( Scrollbar_wrapper::*getUnclippedInnerRect_impl_function_type )( bool ) const;
            
            Scrollbar_exposer.def( 
                "getUnclippedInnerRect_impl"
                , getUnclippedInnerRect_impl_function_type( &Scrollbar_wrapper::default_getUnclippedInnerRect_impl )
                , ( bp::arg("skipAllPixelAlignment") ) );
        
        }
        { //::CEGUI::Element::getUnclippedOuterRect_impl
        
            typedef ::CEGUI::Rectf ( Scrollbar_wrapper::*getUnclippedOuterRect_impl_function_type )( bool ) const;
            
            Scrollbar_exposer.def( 
                "getUnclippedOuterRect_impl"
                , getUnclippedOuterRect_impl_function_type( &Scrollbar_wrapper::default_getUnclippedOuterRect_impl )
                , ( bp::arg("skipAllPixelAlignment") )
                , "! Default implementation of function to return Element's outer rect area.\n" );
        
        }
        { //::CEGUI::Window::getWindowAttachedToCommonAncestor
        
            typedef ::CEGUI::Window const * ( Scrollbar_wrapper::*getWindowAttachedToCommonAncestor_function_type )( ::CEGUI::Window const & ) const;
            
            Scrollbar_exposer.def( 
                "getWindowAttachedToCommonAncestor"
                , getWindowAttachedToCommonAncestor_function_type( &Scrollbar_wrapper::getWindowAttachedToCommonAncestor )
                , ( bp::arg("wnd") )
                , bp::return_value_policy< bp::reference_existing_object >()
                , "*!\n\
            \n\
                Helper function to return the ancestor Window of a wnd that is attached\n\
                as a child to a window that is also an ancestor of a this.  Returns 0\n\
                if a wnd and a this are not part of the same hierachy.\n\
             *\n" );
        
        }
        { //::CEGUI::Window::handleFontRenderSizeChange
        
            typedef bool ( Scrollbar_wrapper::*handleFontRenderSizeChange_function_type )( ::CEGUI::EventArgs const & ) ;
            
            Scrollbar_exposer.def( 
                "handleFontRenderSizeChange"
                , handleFontRenderSizeChange_function_type( &Scrollbar_wrapper::default_handleFontRenderSizeChange )
                , ( bp::arg("args") )
                , "! handler function for when font render size changes.\n" );
        
        }
        { //::CEGUI::Window::initialiseClippers
        
            typedef void ( Scrollbar_wrapper::*initialiseClippers_function_type )( ::CEGUI::RenderingContext const & ) ;
            
            Scrollbar_exposer.def( 
                "initialiseClippers"
                , initialiseClippers_function_type( &Scrollbar_wrapper::initialiseClippers )
                , ( bp::arg("ctx") )
                , "! Helper to intialise the needed clipping for geometry and render surface.\n" );
        
        }
        { //::CEGUI::Window::invalidate_impl
        
            typedef void ( Scrollbar_wrapper::*invalidate_impl_function_type )( bool const ) ;
            
            Scrollbar_exposer.def( 
                "invalidate_impl"
                , invalidate_impl_function_type( &Scrollbar_wrapper::invalidate_impl )
                , ( bp::arg("recursive") )
                , "! helper function to invalidate window and optionally child windows.\n" );
        
        }
        { //::CEGUI::Window::isHit
        
            typedef bool ( ::CEGUI::Window::*isHit_function_type )( ::CEGUI::Vector2f const &,bool const ) const;
            typedef bool ( Scrollbar_wrapper::*default_isHit_function_type )( ::CEGUI::Vector2f const &,bool const ) const;
            
            Scrollbar_exposer.def( 
                "isHit"
                , isHit_function_type(&::CEGUI::Window::isHit)
                , default_isHit_function_type(&Scrollbar_wrapper::default_isHit)
                , ( bp::arg("position"), bp::arg("allow_disabled")=(bool const)(false) ) );
        
        }
        { //::CEGUI::Window::isHitTargetWindow
        
            typedef bool ( Scrollbar_wrapper::*isHitTargetWindow_function_type )( ::CEGUI::Vector2f const &,bool ) const;
            
            Scrollbar_exposer.def( 
                "isHitTargetWindow"
                , isHitTargetWindow_function_type( &Scrollbar_wrapper::isHitTargetWindow )
                , ( bp::arg("position"), bp::arg("allow_disabled") ) );
        
        }
        { //::CEGUI::Element::isInnerRectSizeChanged
        
            typedef bool ( Scrollbar_wrapper::*isInnerRectSizeChanged_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "isInnerRectSizeChanged"
                , isInnerRectSizeChanged_function_type( &Scrollbar_wrapper::isInnerRectSizeChanged )
                , "! helper to return whether the inner rect size has changed\n" );
        
        }
        { //::CEGUI::Window::isPropertyAtDefault
        
            typedef bool ( Scrollbar_wrapper::*isPropertyAtDefault_function_type )( ::CEGUI::Property const * ) const;
            
            Scrollbar_exposer.def( 
                "isPropertyAtDefault"
                , isPropertyAtDefault_function_type( &Scrollbar_wrapper::isPropertyAtDefault )
                , ( bp::arg("property") )
                , "*!\n\
            \n\
                Returns whether a property is at it's default value.\n\
                This function is different from Property.isDefatult as it takes the assigned look'n'feel\n\
                (if the is one) into account.\n\
            *\n" );
        
        }
        { //::CEGUI::Window::isTopOfZOrder
        
            typedef bool ( Scrollbar_wrapper::*isTopOfZOrder_function_type )(  ) const;
            
            Scrollbar_exposer.def( 
                "isTopOfZOrder"
                , isTopOfZOrder_function_type( &Scrollbar_wrapper::isTopOfZOrder )
                , "*!\n\
                \n\
                    Return whether the window is at the top of the Z-Order.  This will\n\
                    correctly take into account 'Always on top' windows as needed.\n\
            \n\
                @return\n\
                    - true if the Window is at the top of the z-order in relation to sibling\n\
                      windows with the same 'always on top' setting.\n\
                    - false if the Window is not at the top of the z-order in relation to\n\
                      sibling windows with the same 'always on top' setting.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::layoutLookNFeelChildWidgets
        
            typedef void ( Scrollbar_wrapper::*layoutLookNFeelChildWidgets_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "layoutLookNFeelChildWidgets"
                , layoutLookNFeelChildWidgets_function_type( &Scrollbar_wrapper::layoutLookNFeelChildWidgets )
                , "mark the rect caches defined on Window invalid (does not affect Element)\n" );
        
        }
        { //::CEGUI::Window::markCachedWindowRectsInvalid
        
            typedef void ( Scrollbar_wrapper::*markCachedWindowRectsInvalid_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "markCachedWindowRectsInvalid"
                , markCachedWindowRectsInvalid_function_type( &Scrollbar_wrapper::markCachedWindowRectsInvalid )
                , "mark the rect caches defined on Window invalid (does not affect Element)\n" );
        
        }
        { //::CEGUI::Window::moveToFront_impl
        
            typedef bool ( Scrollbar_wrapper::*moveToFront_impl_function_type )( bool ) ;
            
            Scrollbar_exposer.def( 
                "moveToFront_impl"
                , moveToFront_impl_function_type( &Scrollbar_wrapper::default_moveToFront_impl )
                , ( bp::arg("wasClicked") )
                , "*!\n\
                \n\
                    Implements move to front behavior.\n\
            \n\
                @return\n\
                    Should return true if some action was taken, or false if there was\n\
                    nothing to be done.\n\
                *\n" );
        
        }
        { //::CEGUI::Element::notifyChildrenOfSizeChange
        
            typedef void ( Scrollbar_wrapper::*notifyChildrenOfSizeChange_function_type )( bool const,bool const ) ;
            
            Scrollbar_exposer.def( 
                "notifyChildrenOfSizeChange"
                , notifyChildrenOfSizeChange_function_type( &Scrollbar_wrapper::notifyChildrenOfSizeChange )
                , ( bp::arg("non_client"), bp::arg("client") ) );
        
        }
        { //::CEGUI::Window::notifyClippingChanged
        
            typedef void ( Scrollbar_wrapper::*notifyClippingChanged_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "notifyClippingChanged"
                , notifyClippingChanged_function_type( &Scrollbar_wrapper::notifyClippingChanged )
                , "*!\n\
            \n\
                Recursively inform all children that the clipping has changed and screen rects\n\
                needs to be recached.\n\
            *\n" );
        
        }
        { //::CEGUI::Window::notifyScreenAreaChanged
        
            typedef void ( ::CEGUI::Window::*notifyScreenAreaChanged_function_type )( bool ) ;
            typedef void ( Scrollbar_wrapper::*default_notifyScreenAreaChanged_function_type )( bool ) ;
            
            Scrollbar_exposer.def( 
                "notifyScreenAreaChanged"
                , notifyScreenAreaChanged_function_type(&::CEGUI::Window::notifyScreenAreaChanged)
                , default_notifyScreenAreaChanged_function_type(&Scrollbar_wrapper::default_notifyScreenAreaChanged)
                , ( bp::arg("recursive")=(bool)(true) ) );
        
        }
        { //::CEGUI::Window::onActivated
        
            typedef void ( Scrollbar_wrapper::*onActivated_function_type )( ::CEGUI::ActivationEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onActivated"
                , onActivated_function_type( &Scrollbar_wrapper::default_onActivated )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when this window has become the active window.\n\
            \n\
                @param e\n\
                    ActivationEventArgs class whose 'otherWindow' field is set to the window\n\
                    that previously was active, or NULL for none.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onAlphaChanged
        
            typedef void ( Scrollbar_wrapper::*onAlphaChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onAlphaChanged"
                , onAlphaChanged_function_type( &Scrollbar_wrapper::default_onAlphaChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's alpha blend value is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onAlwaysOnTopChanged
        
            typedef void ( Scrollbar_wrapper::*onAlwaysOnTopChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onAlwaysOnTopChanged"
                , onAlwaysOnTopChanged_function_type( &Scrollbar_wrapper::default_onAlwaysOnTopChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's always-on-top setting is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onCaptureGained
        
            typedef void ( Scrollbar_wrapper::*onCaptureGained_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onCaptureGained"
                , onCaptureGained_function_type( &Scrollbar_wrapper::default_onCaptureGained )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when this window gains capture of mouse inputs.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onCaptureLost
        
            typedef void ( Scrollbar_wrapper::*onCaptureLost_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onCaptureLost"
                , onCaptureLost_function_type( &Scrollbar_wrapper::default_onCaptureLost )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when this window loses capture of mouse inputs.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onCharacter
        
            typedef void ( Scrollbar_wrapper::*onCharacter_function_type )( ::CEGUI::KeyEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onCharacter"
                , onCharacter_function_type( &Scrollbar_wrapper::default_onCharacter )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a character-key has been pressed while this window\n\
                    has input focus.\n\
            \n\
                @param e\n\
                    KeyEventArgs object whose 'codepoint' field is set to the Unicode code\n\
                    point (encoded as utf32) for the character typed, and whose 'sysKeys'\n\
                    field represents the combination of SystemKey that were active when the\n\
                    event was generated.  All other fields should be considered as 'junk'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onChildAdded
        
            typedef void ( Scrollbar_wrapper::*onChildAdded_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onChildAdded"
                , onChildAdded_function_type( &Scrollbar_wrapper::default_onChildAdded )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a child window is added to this window.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that has been added.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onChildRemoved
        
            typedef void ( Scrollbar_wrapper::*onChildRemoved_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onChildRemoved"
                , onChildRemoved_function_type( &Scrollbar_wrapper::default_onChildRemoved )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a child window is removed from this window.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set the window\n\
                    that has been removed.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onClippingChanged
        
            typedef void ( Scrollbar_wrapper::*onClippingChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onClippingChanged"
                , onClippingChanged_function_type( &Scrollbar_wrapper::default_onClippingChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's setting for being clipped by it's\n\
                    parent is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onDeactivated
        
            typedef void ( Scrollbar_wrapper::*onDeactivated_function_type )( ::CEGUI::ActivationEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onDeactivated"
                , onDeactivated_function_type( &Scrollbar_wrapper::default_onDeactivated )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when this window has lost input focus and has been\n\
                    deactivated.\n\
            \n\
                @param e\n\
                    ActivationEventArgs object whose 'otherWindow' field is set to the\n\
                    window that has now become active, or NULL for none.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onDestructionStarted
        
            typedef void ( Scrollbar_wrapper::*onDestructionStarted_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onDestructionStarted"
                , onDestructionStarted_function_type( &Scrollbar_wrapper::default_onDestructionStarted )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when this window's destruction sequence has begun.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onDisabled
        
            typedef void ( Scrollbar_wrapper::*onDisabled_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onDisabled"
                , onDisabled_function_type( &Scrollbar_wrapper::default_onDisabled )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window is disabled.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onDragDropItemDropped
        
            typedef void ( Scrollbar_wrapper::*onDragDropItemDropped_function_type )( ::CEGUI::DragDropEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onDragDropItemDropped"
                , onDragDropItemDropped_function_type( &Scrollbar_wrapper::default_onDragDropItemDropped )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a DragContainer is dragged over this window.\n\
            \n\
                @param e\n\
                    DragDropEventArgs object initialised as follows:\n\
                    - window field is normaly set to point to 'this' window.\n\
                    - dragDropItem is a pointer to a DragContainer window that triggered\n\
                      the event.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onDragDropItemEnters
        
            typedef void ( Scrollbar_wrapper::*onDragDropItemEnters_function_type )( ::CEGUI::DragDropEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onDragDropItemEnters"
                , onDragDropItemEnters_function_type( &Scrollbar_wrapper::default_onDragDropItemEnters )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a DragContainer is dragged over this window.\n\
            \n\
                @param e\n\
                    DragDropEventArgs object initialised as follows:\n\
                    - window field is normaly set to point to 'this' window.\n\
                    - dragDropItem is a pointer to a DragContainer window that triggered\n\
                      the event.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onDragDropItemLeaves
        
            typedef void ( Scrollbar_wrapper::*onDragDropItemLeaves_function_type )( ::CEGUI::DragDropEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onDragDropItemLeaves"
                , onDragDropItemLeaves_function_type( &Scrollbar_wrapper::default_onDragDropItemLeaves )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a DragContainer is dragged over this window.\n\
            \n\
                @param e\n\
                    DragDropEventArgs object initialised as follows:\n\
                    - window field is normaly set to point to 'this' window.\n\
                    - dragDropItem is a pointer to a DragContainer window that triggered\n\
                      the event.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onEnabled
        
            typedef void ( Scrollbar_wrapper::*onEnabled_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onEnabled"
                , onEnabled_function_type( &Scrollbar_wrapper::default_onEnabled )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window is enabled.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onFontChanged
        
            typedef void ( Scrollbar_wrapper::*onFontChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onFontChanged"
                , onFontChanged_function_type( &Scrollbar_wrapper::default_onFontChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's font is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onHidden
        
            typedef void ( Scrollbar_wrapper::*onHidden_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onHidden"
                , onHidden_function_type( &Scrollbar_wrapper::default_onHidden )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window is hidden.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Element::onHorizontalAlignmentChanged
        
            typedef void ( Scrollbar_wrapper::*onHorizontalAlignmentChanged_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onHorizontalAlignmentChanged"
                , onHorizontalAlignmentChanged_function_type( &Scrollbar_wrapper::default_onHorizontalAlignmentChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the horizontal alignment setting for the element is\n\
                    changed.\n\
            \n\
                @param e\n\
                    ElementEventArgs object initialised as follows:\n\
                    - element field is set to point to the element object who's alignment has\n\
                      changed (typically 'this').\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onIDChanged
        
            typedef void ( Scrollbar_wrapper::*onIDChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onIDChanged"
                , onIDChanged_function_type( &Scrollbar_wrapper::default_onIDChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's client assigned ID is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onInheritsAlphaChanged
        
            typedef void ( Scrollbar_wrapper::*onInheritsAlphaChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onInheritsAlphaChanged"
                , onInheritsAlphaChanged_function_type( &Scrollbar_wrapper::default_onInheritsAlphaChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's setting for inheriting alpha-blending\n\
                    is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onInvalidated
        
            typedef void ( Scrollbar_wrapper::*onInvalidated_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onInvalidated"
                , onInvalidated_function_type( &Scrollbar_wrapper::default_onInvalidated )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when this window gets invalidated.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onKeyDown
        
            typedef void ( Scrollbar_wrapper::*onKeyDown_function_type )( ::CEGUI::KeyEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onKeyDown"
                , onKeyDown_function_type( &Scrollbar_wrapper::default_onKeyDown )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a key as been depressed while this window has input\n\
                    focus.\n\
            \n\
                @param e\n\
                    KeyEventArgs object whose 'scancode' field is set to the Key.Scan value\n\
                    representing the key that was pressed, and whose 'sysKeys' field\n\
                    represents the combination of SystemKey that were active when the event\n\
                    was generated.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onKeyUp
        
            typedef void ( Scrollbar_wrapper::*onKeyUp_function_type )( ::CEGUI::KeyEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onKeyUp"
                , onKeyUp_function_type( &Scrollbar_wrapper::default_onKeyUp )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a key as been released while this window has input\n\
                    focus.\n\
            \n\
                @param e\n\
                    KeyEventArgs object whose 'scancode' field is set to the Key.Scan value\n\
                    representing the key that was released, and whose 'sysKeys' field\n\
                    represents the combination of SystemKey that were active when the event\n\
                    was generated.  All other fields should be considered as 'junk'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMarginChanged
        
            typedef void ( Scrollbar_wrapper::*onMarginChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onMarginChanged"
                , onMarginChanged_function_type( &Scrollbar_wrapper::default_onMarginChanged )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::Window::onMouseButtonUp
        
            typedef void ( Scrollbar_wrapper::*onMouseButtonUp_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onMouseButtonUp"
                , onMouseButtonUp_function_type( &Scrollbar_wrapper::default_onMouseButtonUp )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a mouse button has been released within this\n\
                    window's area.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseClicked
        
            typedef void ( Scrollbar_wrapper::*onMouseClicked_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onMouseClicked"
                , onMouseClicked_function_type( &Scrollbar_wrapper::default_onMouseClicked )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a mouse button has been clicked (that is depressed\n\
                    and then released, within a specified time) within this window's area.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseDoubleClicked
        
            typedef void ( Scrollbar_wrapper::*onMouseDoubleClicked_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onMouseDoubleClicked"
                , onMouseDoubleClicked_function_type( &Scrollbar_wrapper::default_onMouseDoubleClicked )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a mouse button has been double-clicked within this\n\
                    window's area.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseEnters
        
            typedef void ( Scrollbar_wrapper::*onMouseEnters_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onMouseEnters"
                , onMouseEnters_function_type( &Scrollbar_wrapper::default_onMouseEnters )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the mouse cursor has entered this window's area and\n\
                    is actually over some part of this windows surface and not, for\n\
                    instance over a child window - even though technically in those cases\n\
                    the mouse is also within this Window's area, the handler will not be\n\
                    called.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
            \n\
                @see\n\
                    Window.onMouseEntersArea\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseEntersArea
        
            typedef void ( Scrollbar_wrapper::*onMouseEntersArea_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onMouseEntersArea"
                , onMouseEntersArea_function_type( &Scrollbar_wrapper::default_onMouseEntersArea )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the mouse cursor has entered this window's area.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseLeaves
        
            typedef void ( Scrollbar_wrapper::*onMouseLeaves_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onMouseLeaves"
                , onMouseLeaves_function_type( &Scrollbar_wrapper::default_onMouseLeaves )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the mouse cursor is no longer over this window's\n\
                    surface area.  This will be called when the mouse is not over a part\n\
                    of this Window's actual surface - even though technically the mouse is\n\
                    still within the Window's area, for example if the mouse moves over a\n\
                    child window.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
            \n\
                @see\n\
                    Window.onMouseLeavesArea\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseLeavesArea
        
            typedef void ( Scrollbar_wrapper::*onMouseLeavesArea_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onMouseLeavesArea"
                , onMouseLeavesArea_function_type( &Scrollbar_wrapper::default_onMouseLeavesArea )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the mouse cursor has left this window's area.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseMove
        
            typedef void ( Scrollbar_wrapper::*onMouseMove_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onMouseMove"
                , onMouseMove_function_type( &Scrollbar_wrapper::default_onMouseMove )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the mouse cursor has been moved within this window's\n\
                    area.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMouseTripleClicked
        
            typedef void ( Scrollbar_wrapper::*onMouseTripleClicked_function_type )( ::CEGUI::MouseEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onMouseTripleClicked"
                , onMouseTripleClicked_function_type( &Scrollbar_wrapper::default_onMouseTripleClicked )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a mouse button has been triple-clicked within this\n\
                    window's area.\n\
            \n\
                @param e\n\
                    MouseEventArgs object.  All fields are valid.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onMoved
        
            typedef void ( Scrollbar_wrapper::*onMoved_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onMoved"
                , onMoved_function_type( &Scrollbar_wrapper::default_onMoved )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's position changes.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::NamedElement::onNameChanged
        
            typedef void ( Scrollbar_wrapper::*onNameChanged_function_type )( ::CEGUI::NamedElementEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onNameChanged"
                , onNameChanged_function_type( &Scrollbar_wrapper::default_onNameChanged )
                , ( bp::arg("e") )
                , "*!\n\
                 Handler called when the element's name changes.\n\
            \n\
                @param e\n\
                    NamedElementEventArgs object whose 'element' pointer field is set to the element\n\
                    that triggered the event. For this event the trigger element is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Element::onNonClientChanged
        
            typedef void ( Scrollbar_wrapper::*onNonClientChanged_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onNonClientChanged"
                , onNonClientChanged_function_type( &Scrollbar_wrapper::default_onNonClientChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the element's non-client setting, affecting it's\n\
                    position and size relative to it's parent is changed.\n\
            \n\
                @param e\n\
                    ElementEventArgs object whose 'element' pointer field is set to the element\n\
                    that triggered the event. For this event the trigger element is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onParentDestroyChanged
        
            typedef void ( Scrollbar_wrapper::*onParentDestroyChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onParentDestroyChanged"
                , onParentDestroyChanged_function_type( &Scrollbar_wrapper::default_onParentDestroyChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's setting for being destroyed\n\
                    automatically be it's parent is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onParentSized
        
            typedef void ( Scrollbar_wrapper::*onParentSized_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onParentSized"
                , onParentSized_function_type( &Scrollbar_wrapper::default_onParentSized )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when this window's parent window has been resized.  If\n\
                    this window is the root  GUI Sheet window, this call will be made when\n\
                    the display size changes.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set the the\n\
                    window that caused the event; this is typically either this window's\n\
                    parent window, or NULL to indicate the screen size has changed.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onRenderingEnded
        
            typedef void ( Scrollbar_wrapper::*onRenderingEnded_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onRenderingEnded"
                , onRenderingEnded_function_type( &Scrollbar_wrapper::default_onRenderingEnded )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when rendering for this window has ended.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onRenderingStarted
        
            typedef void ( Scrollbar_wrapper::*onRenderingStarted_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onRenderingStarted"
                , onRenderingStarted_function_type( &Scrollbar_wrapper::default_onRenderingStarted )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when rendering for this window has started.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onRotated
        
            typedef void ( Scrollbar_wrapper::*onRotated_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onRotated"
                , onRotated_function_type( &Scrollbar_wrapper::default_onRotated )
                , ( bp::arg("e") ) );
        
        }
        { //::CEGUI::Window::onShown
        
            typedef void ( Scrollbar_wrapper::*onShown_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onShown"
                , onShown_function_type( &Scrollbar_wrapper::default_onShown )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window is shown (made visible).\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onSized
        
            typedef void ( Scrollbar_wrapper::*onSized_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onSized"
                , onSized_function_type( &Scrollbar_wrapper::default_onSized )
                , ( bp::arg("e") )
                , "*************************************************************************\n\
                    Event trigger methods\n\
                *************************************************************************\n\
                *!\n\
                \n\
                    Handler called when the window's size changes.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onTextChanged
        
            typedef void ( Scrollbar_wrapper::*onTextChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onTextChanged"
                , onTextChanged_function_type( &Scrollbar_wrapper::default_onTextChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's text is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onTextParsingChanged
        
            typedef void ( Scrollbar_wrapper::*onTextParsingChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onTextParsingChanged"
                , onTextParsingChanged_function_type( &Scrollbar_wrapper::default_onTextParsingChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the window's setting for whether text parsing is\n\
                    enabled is changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Element::onVerticalAlignmentChanged
        
            typedef void ( Scrollbar_wrapper::*onVerticalAlignmentChanged_function_type )( ::CEGUI::ElementEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onVerticalAlignmentChanged"
                , onVerticalAlignmentChanged_function_type( &Scrollbar_wrapper::default_onVerticalAlignmentChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the vertical alignment setting for the element is\n\
                    changed.\n\
            \n\
                @param e\n\
                    ElementEventArgs object initialised as follows:\n\
                    - element field is set to point to the element object who's alignment has\n\
                      changed (typically 'this').\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onWindowRendererAttached
        
            typedef void ( Scrollbar_wrapper::*onWindowRendererAttached_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onWindowRendererAttached"
                , onWindowRendererAttached_function_type( &Scrollbar_wrapper::default_onWindowRendererAttached )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when a new window renderer object is attached.\n\
            \n\
                @param e\n\
                    WindowEventArgs object initialised as follows:\n\
                    - window field is set to point to the Window object that just got a new\n\
                      window renderer attached. (typically 'this').\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onWindowRendererDetached
        
            typedef void ( Scrollbar_wrapper::*onWindowRendererDetached_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onWindowRendererDetached"
                , onWindowRendererDetached_function_type( &Scrollbar_wrapper::default_onWindowRendererDetached )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the currently attached window renderer object is detached.\n\
            \n\
                @param e\n\
                    WindowEventArgs object initialised as follows:\n\
                    - window field is set to point to the Window object that just got lost its\n\
                      window renderer. (typically 'this').\n\
                *\n" );
        
        }
        { //::CEGUI::Window::onZChange_impl
        
            typedef void ( Scrollbar_wrapper::*onZChange_impl_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "onZChange_impl"
                , onZChange_impl_function_type( &Scrollbar_wrapper::default_onZChange_impl )
                , "*!\n\
            \n\
                Notify 'this' and all siblings of a ZOrder change event\n\
            *\n" );
        
        }
        { //::CEGUI::Window::onZChanged
        
            typedef void ( Scrollbar_wrapper::*onZChanged_function_type )( ::CEGUI::WindowEventArgs & ) ;
            
            Scrollbar_exposer.def( 
                "onZChanged"
                , onZChanged_function_type( &Scrollbar_wrapper::default_onZChanged )
                , ( bp::arg("e") )
                , "*!\n\
                \n\
                    Handler called when the z-order position of this window has changed.\n\
            \n\
                @param e\n\
                    WindowEventArgs object whose 'window' pointer field is set to the window\n\
                    that triggered the event.  For this event the trigger window is always\n\
                    'this'.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::performChildWindowLayout
        
            typedef void ( ::CEGUI::Window::*performChildWindowLayout_function_type )( bool,bool ) ;
            typedef void ( Scrollbar_wrapper::*default_performChildWindowLayout_function_type )( bool,bool ) ;
            
            Scrollbar_exposer.def( 
                "performChildWindowLayout"
                , performChildWindowLayout_function_type(&::CEGUI::Window::performChildWindowLayout)
                , default_performChildWindowLayout_function_type(&Scrollbar_wrapper::default_performChildWindowLayout)
                , ( bp::arg("nonclient_sized_hint")=(bool)(false), bp::arg("client_sized_hint")=(bool)(false) ) );
        
        }
        { //::CEGUI::Window::performCopy
        
            typedef bool ( ::CEGUI::Window::*performCopy_function_type )( ::CEGUI::Clipboard & ) ;
            typedef bool ( Scrollbar_wrapper::*default_performCopy_function_type )( ::CEGUI::Clipboard & ) ;
            
            Scrollbar_exposer.def( 
                "performCopy"
                , performCopy_function_type(&::CEGUI::Window::performCopy)
                , default_performCopy_function_type(&Scrollbar_wrapper::default_performCopy)
                , ( bp::arg("clipboard") ) );
        
        }
        { //::CEGUI::Window::performCut
        
            typedef bool ( ::CEGUI::Window::*performCut_function_type )( ::CEGUI::Clipboard & ) ;
            typedef bool ( Scrollbar_wrapper::*default_performCut_function_type )( ::CEGUI::Clipboard & ) ;
            
            Scrollbar_exposer.def( 
                "performCut"
                , performCut_function_type(&::CEGUI::Window::performCut)
                , default_performCut_function_type(&Scrollbar_wrapper::default_performCut)
                , ( bp::arg("clipboard") ) );
        
        }
        { //::CEGUI::Window::performPaste
        
            typedef bool ( ::CEGUI::Window::*performPaste_function_type )( ::CEGUI::Clipboard & ) ;
            typedef bool ( Scrollbar_wrapper::*default_performPaste_function_type )( ::CEGUI::Clipboard & ) ;
            
            Scrollbar_exposer.def( 
                "performPaste"
                , performPaste_function_type(&::CEGUI::Window::performPaste)
                , default_performPaste_function_type(&Scrollbar_wrapper::default_performPaste)
                , ( bp::arg("clipboard") ) );
        
        }
        { //::CEGUI::Window::populateGeometryBuffer
        
            typedef void ( Scrollbar_wrapper::*populateGeometryBuffer_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "populateGeometryBuffer"
                , populateGeometryBuffer_function_type( &Scrollbar_wrapper::default_populateGeometryBuffer )
                , "*!\n\
                \n\
                    Update the rendering cache.\n\
            \n\
                    Populates the Window's GeometryBuffer ready for rendering.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::queueGeometry
        
            typedef void ( Scrollbar_wrapper::*queueGeometry_function_type )( ::CEGUI::RenderingContext const & ) ;
            
            Scrollbar_exposer.def( 
                "queueGeometry"
                , queueGeometry_function_type( &Scrollbar_wrapper::queueGeometry )
                , ( bp::arg("ctx") )
                , "*!\n\
                \n\
                    Perform drawing operations concerned with positioning, clipping and\n\
                    queueing of window geometry to RenderingSurfaces.\n\
            \n\
                \note\n\
                    This function is a sub-function of drawSelf and is provided to make it\n\
                    easier to override drawSelf without needing to duplicate large sections\n\
                    of the code from the default implementation.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::releaseRenderingWindow
        
            typedef void ( Scrollbar_wrapper::*releaseRenderingWindow_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "releaseRenderingWindow"
                , releaseRenderingWindow_function_type( &Scrollbar_wrapper::releaseRenderingWindow )
                , "! helper to clean up the auto RenderingWindow surface\n" );
        
        }
        { //::CEGUI::Window::removeChild_impl
        
            typedef void ( Scrollbar_wrapper::*removeChild_impl_function_type )( ::CEGUI::Element * ) ;
            
            Scrollbar_exposer.def( 
                "removeChild_impl"
                , removeChild_impl_function_type( &Scrollbar_wrapper::default_removeChild_impl )
                , ( bp::arg("element") )
                , "*!\n\
            opydoc Element.removeChild_impl\n\
            *\n" );
        
        }
        { //::CEGUI::Window::removeWindowFromDrawList
        
            typedef void ( Scrollbar_wrapper::*removeWindowFromDrawList_function_type )( ::CEGUI::Window const & ) ;
            
            Scrollbar_exposer.def( 
                "removeWindowFromDrawList"
                , removeWindowFromDrawList_function_type( &Scrollbar_wrapper::removeWindowFromDrawList )
                , ( bp::arg("wnd") )
                , "*!\n\
                \n\
                    Removes the window from the drawing list.  If the window is not attached\n\
                    to the drawing list then nothing happens.\n\
            \n\
                @param wnd\n\
                    Window object to be removed from the drawing list.\n\
            \n\
                @return\n\
                    Nothing.\n\
                *\n" );
        
        }
        { //::CEGUI::Element::setArea
        
            typedef void ( ::CEGUI::Element::*setArea_function_type )( ::CEGUI::UVector2 const &,::CEGUI::USize const & ) ;
            typedef void ( Scrollbar_wrapper::*default_setArea_function_type )( ::CEGUI::UVector2 const &,::CEGUI::USize const & ) ;
            
            Scrollbar_exposer.def( 
                "setArea"
                , setArea_function_type(&::CEGUI::Element::setArea)
                , default_setArea_function_type(&Scrollbar_wrapper::default_setArea)
                , ( bp::arg("pos"), bp::arg("size") ) );
        
        }
        { //::CEGUI::Element::setArea
        
            typedef void ( ::CEGUI::Element::*setArea_function_type )( ::CEGUI::UDim const &,::CEGUI::UDim const &,::CEGUI::UDim const &,::CEGUI::UDim const & ) ;
            
            Scrollbar_exposer.def( 
                "setArea"
                , setArea_function_type( &::CEGUI::Element::setArea )
                , ( bp::arg("xpos"), bp::arg("ypos"), bp::arg("width"), bp::arg("height") )
                , "!  overload\n" );
        
        }
        { //::CEGUI::Element::setArea
        
            typedef void ( ::CEGUI::Element::*setArea_function_type )( ::CEGUI::URect const & ) ;
            
            Scrollbar_exposer.def( 
                "setArea"
                , setArea_function_type( &::CEGUI::Element::setArea )
                , ( bp::arg("area") )
                , "!  overload\n" );
        
        }
        { //::CEGUI::Window::setArea_impl
        
            typedef void ( Scrollbar_wrapper::*setArea_impl_function_type )( ::CEGUI::UVector2 const &,::CEGUI::USize const &,bool,bool ) ;
            
            Scrollbar_exposer.def( 
                "setArea_impl"
                , setArea_impl_function_type( &Scrollbar_wrapper::default_setArea_impl )
                , ( bp::arg("pos"), bp::arg("size"), bp::arg("topLeftSizing")=(bool)(false), bp::arg("fireEvents")=(bool)(true) )
                , "! opydoc Element.setArea_impl\n" );
        
        }
        { //::CEGUI::Element::setHorizontalAlignment
        
            typedef void ( ::CEGUI::Element::*setHorizontalAlignment_function_type )( ::CEGUI::HorizontalAlignment const ) ;
            typedef void ( Scrollbar_wrapper::*default_setHorizontalAlignment_function_type )( ::CEGUI::HorizontalAlignment const ) ;
            
            Scrollbar_exposer.def( 
                "setHorizontalAlignment"
                , setHorizontalAlignment_function_type(&::CEGUI::Element::setHorizontalAlignment)
                , default_setHorizontalAlignment_function_type(&Scrollbar_wrapper::default_setHorizontalAlignment)
                , ( bp::arg("alignment") ) );
        
        }
        { //::CEGUI::Window::setLookNFeel
        
            typedef void ( ::CEGUI::Window::*setLookNFeel_function_type )( ::CEGUI::String const & ) ;
            typedef void ( Scrollbar_wrapper::*default_setLookNFeel_function_type )( ::CEGUI::String const & ) ;
            
            Scrollbar_exposer.def( 
                "setLookNFeel"
                , setLookNFeel_function_type(&::CEGUI::Window::setLookNFeel)
                , default_setLookNFeel_function_type(&Scrollbar_wrapper::default_setLookNFeel)
                , ( bp::arg("look") ) );
        
        }
        { //::CEGUI::Window::setMargin
        
            typedef void ( ::CEGUI::Window::*setMargin_function_type )( ::CEGUI::UBox const & ) ;
            typedef void ( Scrollbar_wrapper::*default_setMargin_function_type )( ::CEGUI::UBox const & ) ;
            
            Scrollbar_exposer.def( 
                "setMargin"
                , setMargin_function_type(&::CEGUI::Window::setMargin)
                , default_setMargin_function_type(&Scrollbar_wrapper::default_setMargin)
                , ( bp::arg("margin") ) );
        
        }
        { //::CEGUI::NamedElement::setName
        
            typedef void ( ::CEGUI::NamedElement::*setName_function_type )( ::CEGUI::String const & ) ;
            typedef void ( Scrollbar_wrapper::*default_setName_function_type )( ::CEGUI::String const & ) ;
            
            Scrollbar_exposer.def( 
                "setName"
                , setName_function_type(&::CEGUI::NamedElement::setName)
                , default_setName_function_type(&Scrollbar_wrapper::default_setName)
                , ( bp::arg("name") ) );
        
        }
        { //::CEGUI::Window::setParent
        
            typedef void ( Scrollbar_wrapper::*setParent_function_type )( ::CEGUI::Element * ) ;
            
            Scrollbar_exposer.def( 
                "setParent"
                , setParent_function_type( &Scrollbar_wrapper::default_setParent )
                , ( bp::arg("parent") )
                , "*!\n\
                \n\
                    Set the parent window for this window object.\n\
            \n\
                @param parent\n\
                    Pointer to a Window object that is to be assigned as the parent to this\n\
                    Window.\n\
            \n\
                @return\n\
                    Nothing\n\
                *\n" );
        
        }
        { //::CEGUI::Element::setVerticalAlignment
        
            typedef void ( ::CEGUI::Element::*setVerticalAlignment_function_type )( ::CEGUI::VerticalAlignment const ) ;
            typedef void ( Scrollbar_wrapper::*default_setVerticalAlignment_function_type )( ::CEGUI::VerticalAlignment const ) ;
            
            Scrollbar_exposer.def( 
                "setVerticalAlignment"
                , setVerticalAlignment_function_type(&::CEGUI::Element::setVerticalAlignment)
                , default_setVerticalAlignment_function_type(&Scrollbar_wrapper::default_setVerticalAlignment)
                , ( bp::arg("alignment") ) );
        
        }
        { //::CEGUI::EventSet::subscribeScriptedEvent
        
            typedef ::CEGUI::RefCounted< CEGUI::BoundSlot > ( ::CEGUI::EventSet::*subscribeScriptedEvent_function_type )( ::CEGUI::String const &,::CEGUI::String const & ) ;
            typedef ::CEGUI::RefCounted< CEGUI::BoundSlot > ( Scrollbar_wrapper::*default_subscribeScriptedEvent_function_type )( ::CEGUI::String const &,::CEGUI::String const & ) ;
            
            Scrollbar_exposer.def( 
                "subscribeScriptedEvent"
                , subscribeScriptedEvent_function_type(&::CEGUI::EventSet::subscribeScriptedEvent)
                , default_subscribeScriptedEvent_function_type(&Scrollbar_wrapper::default_subscribeScriptedEvent)
                , ( bp::arg("name"), bp::arg("subscriber_name") ) );
        
        }
        { //::CEGUI::EventSet::subscribeScriptedEvent
        
            typedef ::CEGUI::RefCounted< CEGUI::BoundSlot > ( ::CEGUI::EventSet::*subscribeScriptedEvent_function_type )( ::CEGUI::String const &,unsigned int,::CEGUI::String const & ) ;
            typedef ::CEGUI::RefCounted< CEGUI::BoundSlot > ( Scrollbar_wrapper::*default_subscribeScriptedEvent_function_type )( ::CEGUI::String const &,unsigned int,::CEGUI::String const & ) ;
            
            Scrollbar_exposer.def( 
                "subscribeScriptedEvent"
                , subscribeScriptedEvent_function_type(&::CEGUI::EventSet::subscribeScriptedEvent)
                , default_subscribeScriptedEvent_function_type(&Scrollbar_wrapper::default_subscribeScriptedEvent)
                , ( bp::arg("name"), bp::arg("group"), bp::arg("subscriber_name") ) );
        
        }
        { //::CEGUI::Window::transferChildSurfaces
        
            typedef void ( Scrollbar_wrapper::*transferChildSurfaces_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "transferChildSurfaces"
                , transferChildSurfaces_function_type( &Scrollbar_wrapper::transferChildSurfaces )
                , "! transfer RenderingSurfaces to be owned by our target RenderingSurface.\n" );
        
        }
        { //::CEGUI::Window::update
        
            typedef void ( ::CEGUI::Window::*update_function_type )( float ) ;
            typedef void ( Scrollbar_wrapper::*default_update_function_type )( float ) ;
            
            Scrollbar_exposer.def( 
                "update"
                , update_function_type(&::CEGUI::Window::update)
                , default_update_function_type(&Scrollbar_wrapper::default_update)
                , ( bp::arg("elapsed") ) );
        
        }
        { //::CEGUI::Window::updateGeometryRenderSettings
        
            typedef void ( Scrollbar_wrapper::*updateGeometryRenderSettings_function_type )(  ) ;
            
            Scrollbar_exposer.def( 
                "updateGeometryRenderSettings"
                , updateGeometryRenderSettings_function_type( &Scrollbar_wrapper::updateGeometryRenderSettings )
                , "*!\n\
            \n\
                Update position and clip region on this Windows geometry  rendering\n\
                surface.\n\
            *\n" );
        
        }
        { //::CEGUI::Window::updateSelf
        
            typedef void ( Scrollbar_wrapper::*updateSelf_function_type )( float ) ;
            
            Scrollbar_exposer.def( 
                "updateSelf"
                , updateSelf_function_type( &Scrollbar_wrapper::default_updateSelf )
                , ( bp::arg("elapsed") )
                , "*************************************************************************\n\
                    Implementation Functions\n\
                *************************************************************************\n\
                *!\n\
                \n\
                    Perform actual update processing for this Window.\n\
            \n\
                @param elapsed\n\
                    float value indicating the number of seconds elapsed since the last\n\
                    update call.\n\
            \n\
                @return\n\
                    Nothing.\n\
                *\n" );
        
        }
        { //::CEGUI::Window::writeAutoChildWindowXML
        
            typedef bool ( Scrollbar_wrapper::*writeAutoChildWindowXML_function_type )( ::CEGUI::XMLSerializer & ) const;
            
            Scrollbar_exposer.def( 
                "writeAutoChildWindowXML"
                , writeAutoChildWindowXML_function_type( &Scrollbar_wrapper::default_writeAutoChildWindowXML )
                , ( bp::arg("xml_stream") ) );
        
        }
        { //::CEGUI::Window::writeChildWindowsXML
        
            typedef int ( Scrollbar_wrapper::*writeChildWindowsXML_function_type )( ::CEGUI::XMLSerializer & ) const;
            
            Scrollbar_exposer.def( 
                "writeChildWindowsXML"
                , writeChildWindowsXML_function_type( &Scrollbar_wrapper::default_writeChildWindowsXML )
                , ( bp::arg("xml_stream") ) );
        
        }
        { //::CEGUI::Window::writePropertiesXML
        
            typedef int ( Scrollbar_wrapper::*writePropertiesXML_function_type )( ::CEGUI::XMLSerializer & ) const;
            
            Scrollbar_exposer.def( 
                "writePropertiesXML"
                , writePropertiesXML_function_type( &Scrollbar_wrapper::default_writePropertiesXML )
                , ( bp::arg("xml_stream") ) );
        
        }
        { //::CEGUI::Window::writeXMLToStream
        
            typedef void ( ::CEGUI::Window::*writeXMLToStream_function_type )( ::CEGUI::XMLSerializer & ) const;
            typedef void ( Scrollbar_wrapper::*default_writeXMLToStream_function_type )( ::CEGUI::XMLSerializer & ) const;
            
            Scrollbar_exposer.def( 
                "writeXMLToStream"
                , writeXMLToStream_function_type(&::CEGUI::Window::writeXMLToStream)
                , default_writeXMLToStream_function_type(&Scrollbar_wrapper::default_writeXMLToStream)
                , ( bp::arg("xml_stream") ) );
        
        }
    }

}
